/** \mainpage APCI-1710 API functions documentation
* \section intro_sec Introduction
* See the modules chapter to view the functions \n
*/

 /** @file PCI1710.H
 * Header file of the APCI-1710
 *
 *
 *  @author C. Guinot
 *  @date 15.07.2009
 *
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009  ADDI-DATA GmbH for the source code of this module.
 *
*  ADDI-DATA GmbH
*  Airpark Business Center
*  Airport Boulevard B210
*  77836 Rheinmnster
*  Germany
*  Tel: +49(0)7229/1847-0
*  Fax: +49(0)7229/1847-200
*  http://www.addi-data-com
*  info@addi-data.com
 *
 * @endverbatim
 */

#include <stdio.H>
#include <dos.H>
#include <windows.h>
#include <winioctl.h>
#include <io.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <math.h>
#include <string.h>

#include "define.h"

#ifdef __cplusplus
	extern "C" {
#endif

/** \defgroup PCI1710 xPCI-1710 functions
 * @{
 */
/* @} */

/** \addtogroup General xPCI-1710 general functions
* \ingroup PCI1710
 * @{
 *
 */

/*i_PCI1710_GetModuleConfiguration*/
/** Get the configuration of the module
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module selection
 * @param[out] pdw_ModuleConfiguration Contains the 4 ASCII codes of the configuration
 *               \li bits 0 -> 7   ASCII code (version low)
 *               \li bits 8 -> 15  ASCII code (version high)
 *               \li bits 16 -> 23 ASCII code (functionality second digit)
 *               \li bits 24 -> 31 ASCII code (functionality first digit)
 *
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong \n
 * @retval -2 : Wrong module selection \n
 * @retval -100 : IOCTL failed \n
 */
_INT_ i_PCI1710_GetModuleConfiguration(HANDLE h_DeviceHandle, BYTE b_ModuleNbr, PDWORD pdw_ModuleConfiguration);

/*i_PCI1710_ConfigureAllModule*/
/** Configure the four module of the PCI-1710 board. \n
 * The available files are :
 * \li 82X54.CFG
 * \li CHRONOS.CFG
 * \li DGI_IO.CFG
 * \li ETM.CFG
 * \li IMP_CPT.CFG
 * \li INC_CPT.CFG
 * \li PWM.CFG
 * \li SSI.CFG
 * \li SSI_MON.CFG
 * \li TOR.CFG
 * \li TTL_IO.CFG
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] pc_FileName1 Name of the configuration file for function module 1
 * @param[in] pc_FileName2 Name of the configuration file for function module 2
 * @param[in] pc_FileName3 Name of the configuration file for function module 3
 * @param[in] pc_FileName4 Name of the configuration file for function module 4
 * @param[out] pdw_WriteAddressError If an error occurs, return the address of the read/write register
 * @return	  > 0 : Warning \n
 *			 	0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Error while loading the file \n
 *			   -3 : Error while decoding Altera file \n
 *			   -4 : Error while erasing flash \n
 *			   -5 : Program flash error \n
 *			   -6 : Error while reading the flash \n
 *			   -7 : Comparison between reading and writing of the flash is not correct \n
 *			   -8 : Error while loading Flex component \n
 *			   -9 : Wrong loading of the flex component \n
 *			   -10 : Error while updating the configuration
 */
_INT_ i_PCI1710_ConfigureAllModule(HANDLE h_DeviceHandle,
									PCHAR_ pc_FileName1,
									PCHAR_ pc_FileName2,
									PCHAR_ pc_FileName3,
									PCHAR_ pc_FileName4,
									PDWORD pdw_WriteAddressError);


/**  Return the number of xPCI-1710 board found (pb_NbrOfBoard)
*
*
* @param[out] pb_NbrOfBoards Return the number of board found
* @return    > 0 : Warning \n
*              0 : No Error                                                   */
_INT_ i_PCI1710_GetNumberOfBoards (PBYTE pb_NbrOfBoards);


/** Get device information of the board.
*
* @param[in] b_BoardIndex Index of the board
* @param[in] dw_IdentifierStringSize size of the identifier parameter
* @param[out] pc_Identifier Identifier of the board
* @param[out] pdw_UINumber This number is typically a user-perceived slot number, such as a number printed next to the slot on the board, or some other number that makes locating the physical device easier for the user. If the device is on a bus that has no UI number convention, or if the bus driver for the device cannot determine the UI number, this value is 0xFFFFFFFF.
* @param[out] pdw_DeviceNumber Device number.
* @param[out] pdw_BusNumber Bus number.
* @param[out] pdw_BaseAddress0 Base address 0 of the board
* @param[out] pdw_BaseAddress1 Base address 1 of the board
* @param[out] pb_Interrupt Interrupt number of the board
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : No device available \n
*             -2 : Wrong device index parameter \n
*             -3 : Get the classe device information error \n
*             -4 : Enum Interface error \n
*             -5 :  Memory allocation error \n
*             -6 : Get device interface detail error \n
*             -7 : Open the device error \n
*             -8 : Get device information error \n
*/
_INT_ i_PCI1710_GetBoardInformation(BYTE b_BoardIndex,
			 					    PCHAR pc_Identifier,
			 					    DWORD dw_IdentifierStringSize,
								    PDWORD pdw_UINumber,
								    PDWORD pdw_DeviceNumber,
								    PDWORD pdw_BusNumber,
								    PDWORD pdw_BaseAddress0,
								    PDWORD pdw_BaseAddress1,
								    PBYTE pb_Interrupt);


/** Open the board with the index : b_BoardIndex. A handle is returned to the \n
* user which allows to use the driver functions. \n
*
* @param[in] b_BoardIndex Index of the board to open
* @param[out] ph_DeviceHandle Handle of the selected xPCI-1710 board for using the functions
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : Not available board index \n
*             -2 : Board not present \n
*             -3 : No handle is available for the board      */

_INT_ i_PCI1710_OpenBoardViaIndex (BYTE b_BoardIndex,
                                   PHANDLE  ph_DeviceHandle);

/** Open the board with the indentifier : pc_Identifier. A handle is returned to the \n
* user which allows to use the following functions. \n
* Handles allow to operate several boards.
*
* @param[in] pc_Identifier Identifier of the board to open
* @param[out] ph_DeviceHandle Handle of the board xPCI-1710 for using the functions
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : No device available \n
*             -2 : Wrong identifier parameter \n
*             -3 : Device already opened \n
*             -4 : Wrong GUID Class code \n
*             -5 : Instance does not exist \n
*             -6 : Memory allocation error \n
*             -7 : Symbolic link name error \n
*             -8 : Create file error \n
*             -9 : Get identifier error \n
*             -10 : no device found with this identifier
*/

_INT_ i_PCI1710_OpenBoardViaIdentifier (PCHAR pc_Identifier,
                                        PHANDLE ph_DeviceHandle);

/** Releases the handle of the board. Blocks the access to the board.
*
* @param[in] h_DeviceHandle Handle of the board
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : The device handle parameter is wrong */

_INT_ i_PCI1710_CloseBoard (HANDLE  h_DeviceHandle);

/** Return the type of the hardware of the PCI-1710
 *
 * @param[in] b_DeviceHandle Handle of the board
 * @param[out] pb_HardwareType Type of the hardware (0 -> 10K10, 1 -> 10K20) \n
 *								The hardware type is necessessary to be known, for the user to configure
 *								the modules. There is two subdirectories containing the config files.
 *								The path given to the function must be the good one, or the card could be destroyed.
 * @return    > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong
 */
_INT_ i_PCI1710_GetBoardHardwareType(HANDLE b_DeviceHandle,
									PBYTE_ pb_HardwareType);

/* @} */

/** \addtogroup Interrupt xPCI-1710 interrupt management functions
 * \ingroup PCI1710
 * @{
 *
 */
/** Install an interrupt callback function.\n

*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] v_FunctionName Address of the callback function     \n
*
* dw_Status : D0 : Interrupt FIFO Overflow Status, 0: no overflow, 1: overflow \n
* dw_InterruptSource = b_ModuleMask of the 32 bits driver \n
* \htmlonly
* <table align="center" border=1 cellspacing=0 cellpadding=3>
* 	<tr>
*		<td>Module</td>
*		<td>Source</td>
* 	</tr>
* 	<tr>
*		<td>0</td>
*		<td>0x1</td>
* 	</tr>
* 	<tr>
*		<td>1</td>
*		<td>0x2</td>
* 	</tr>
* 	<tr>
*		<td>2</td>
*		<td>0x4</td>
* 	</tr>
* 	<tr>
*		<td>3</td>
*		<td>0x8</td>
* 	</tr>
* </table>
 \endhtmlonly
* dw_InterruptMask = dw_InterruptMask of the 32 bits driver \n
* pdw_Args[0] = dw_CounterLatchValue of the 32 bits driver \n
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : The device handle parameter is wrong
**/
_INT_ i_PCI1710_SetBoardIntRoutine (HANDLE h_DeviceHandle,
			 					    void (far pascal * v_FunctionName) (HANDLE   h_DeviceHandle,
									                                    DWORD   dw_Status,
                                                                        DWORD   dw_InterruptSource,
                                                                        DWORD   dw_InterruptMask,
                                                                        DWORD   dw_ArgsSize,
                                                                        PDWORD pdw_Args));
/** Deinstall the interrupt callback function.
*
* @param[in] h_DeviceHandle Handle of the board
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : The device handle parameter is wrong */
_INT_ i_PCI1710_ResetBoardIntRoutine (HANDLE h_DeviceHandle);

/* @} */

/*Function's Name   : i_PCI1710_GetDeviceDriverVersion*/
/** Return the version of the device driver.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[out] pdw_Version Version. sample : 0x01010000 -> version 1.01
* @return    > 0 : Warning \n
*              0 : No Error \n
*             -1 : No device available \n
*             -2 : Wrong device handle parameter       */
_INT_ i_PCI1710_GetDeviceDriverVersion(HANDLE h_DeviceHandle, PDWORD pdw_Version);

/*Function's Name   : i_PCI1710_GetDLLVersion*/
/** Return the version of the DLL.
*
* @param[out] pdw_Version Version. sample : 0x01010910 -> version 1.01 september 2010
* @return    > 0 : Warning \n
*              0 : No Error \n                    */
_INT_ i_PCI1710_GetDLLVersion (PDWORD pdw_Version);

/** \addtogroup INC_CPT xPCI-1710 incremental counter functions
* \ingroup PCI1710
* @{
 *
 */
 
 /** Disables or enables the software filter in the selected module for the inputs A, B, C and D.
*   This function is only available for incremental counter and impulse counter
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured
* @param[in] b_PCIInputClock Selection of the bus clock
*             \li 30: 30 MHz (Only for Incremental counter module)
*             \li 33: 33 MHz
*             \li 40: 40 MHz
* @param[in] b_Filter Selection of the filter for the inputs A, B, C and D
* \htmlonly
*           <li> 33 Mhz clock </li>
*			<ul>
*               0: filter not used <br>
*               1: 121 ns <br>
*               2: 182 ns <br>
*               3: 242 ns <br>
*               4: 303 ns <br>
*               5: 364 ns <br>
*               6: 424 ns <br>
*               7: 485 ns <br>
*               8: 545 ns <br>
*               9: 606 ns <br>
*               10: 667 ns <br>
*               11: 727 ns <br>
*               12: 788 ns <br>
*               13: 848 ns <br>
*               14: 909 ns <br>
*               15: 970 ns <br>
*           </ul>
*           <li> 40 Mhz clock </li>
*           <ul>
*               0: filter not used <br>
*               1: 100 ns <br>
*               2: 150 ns <br>
*               3: 200 ns <br>
*               4: 250 ns <br>
*               5: 300 ns <br>
*               6: 350 ns <br>
*               7: 400 ns <br>
*               8: 450 ns <br>
*               9: 500 ns <br>
*               10: 550 ns <br>
*               11: 600 ns <br>
*               12: 650 ns <br>
*               13: 700 ns <br>
*               14: 750 ns <br>
*               15: 800 ns <br>
*           </ul>
* \endhtmlonly
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The module is not a counter module or a pulse encoder module
* @retval -4 : The selected PCI input clock is wrong
* @retval -5 : The selected filter time is wrong
* @retval -6 : The 40 MHz quartz is not available on the board
*/
_INT_ 	i_PCI1710_SetInputFilter	(HANDLE h_DeviceHandle,
					                 BYTE b_ModuleNbr,
                                     BYTE b_PCIInputClock,
					                 BYTE b_Filter);
 
 /** Disables or enables the software filter in the selected module for the inputs E, F and G.
*   This function is only available for incremental counter version SC30 or higher
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured
* @param[in] b_Filter Selection of the filter for the inputs E, F and G
* \htmlonly
*           <li> 40 Mhz clock </li>
*           <ul>
*               0: filter not used <br>
*               1: 100 ns <br>
*               2: 150 ns <br>
*               3: 200 ns <br>
*               4: 250 ns <br>
*               5: 300 ns <br>
*               6: 350 ns <br>
*               7: 400 ns <br>
*               8: 450 ns <br>
*               9: 500 ns <br>
*               10: 550 ns <br>
*               11: 600 ns <br>
*               12: 650 ns <br>
*               13: 700 ns <br>
*               14: 750 ns <br>
*               15: 800 ns <br>
*           </ul>
* \endhtmlonly
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The module is not a counter module
* @retval -4 : The module is a counter module but the version is wrong (it has to be SC30 or higher)
* @retval -5 : The selected filter time is wrong
* @retval -6 : The 40 MHz quartz is not available on the board
*/
_INT_ 	i_PCI1710_SetInputFilterEFG	(HANDLE h_DeviceHandle,
					                 BYTE b_ModuleNbr,
					                 BYTE b_Filter);


/** Configures the counter operation mode of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_CounterRange Selection of the counter range (0: 32-bit counter, 16: 16-bit counter)
* @param[in] b_FirstCounterModus Operation mode of the first counter (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode)
* @param[in] b_FirstCounterOption Option of the first counter (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or single, 0: hysteresis off, 96: hysteresis on)
* @param[in] b_SecondCounterModus Operation mode of the second counter (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode)
* @param[in] b_SecondCounterOption Option of the second counter (if second mode is direct, 0: decrement, 96: increment; if second counter mode is quadruple, double or single, 0: hysteresis off, 96: hysteresis on)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The module is not a counter module
* @retval -3 : The selected counter range is wrong
* @retval -4 : The selected operation mode of the first counter is wrong
* @retval -5 : The selected operation option of the first counter is wrong
* @retval -6 : The selected operation mode of the second counter is wrong
* @retval -7 : The selected operation option of the second counter is wrong
*/
_INT_   i_PCI1710_InitCounter (HANDLE h_DeviceHandle,
				               BYTE b_ModuleNbr,
				               BYTE b_CounterRange,
				               BYTE b_FirstCounterModus,
				               BYTE b_FirstCounterOption,
				               BYTE b_SecondCounterModus,
				               BYTE b_SecondCounterOption);

/** Configures the H output behavior. A pulse of 400ns can be generated by the compare event.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_SourceSelect Source selection (0: manually set using SetDigitalChlOn/Off, 1: pulses are generated by compare events)
* @retval -1    The device handle parameter is wrong
* @retval -2    The selected module number is wrong
* @retval -3    The source selection parameter is wrong
* @retval -4    The selected module is not compatible with this function (SC3x is required)
* @retval -5    The counter has not been initialised (see the i_PCI1710_InitCounter function)
*/
_INT_ 	i_PCI1710_ConfigDigitalChlUse(HANDLE h_DeviceHandle,
									   BYTE b_ModuleNbr,
									   BYTE b_SourceSelect);

/** Sets the 16-bit compare value. An interrupt is generated for each multiple of the compare value.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] dw_CompareValue 16-bit compare value
* @param[in] b_CompareHysteresis Compare hysteresis value
* @retval  0    No error
* @retval -1    The device handle parameter is wrong
* @retval -2    The selected module number is wrong
* @retval -3    The selected module is not compatible with this function (SC3x is required)
* @retval -4    The counter has not been initialised (see the i_PCIe1710_InitCounter function)
* @retval -5    The compare value is wrong
*/
_INT_   i_PCI1710_InitModuloCompareLogic	(HANDLE h_DeviceHandle,
											BYTE b_ModuleNbr,
											DWORD dw_CompareValue,
											BYTE b_CompareHysteresis);
									   
/** Reads the compare latch register value from the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be read (0 to 3)
* @param[out] pdw_LatchValue Latch register value
* @retval  0    No error
* @retval -1    The device handle parameter is wrong
* @retval -2    The selected module number is wrong
* @retval -3    The selected module is not compatible with this function (SC3x is required)
* @retval -4    The counter has not been initialised (see the i_PCIe1710_InitCounter function)
*/
_INT_   i_PCI1710_ReadCompareLatchRegister	(HANDLE h_DeviceHandle,
											BYTE b_ModuleNbr,
											PDWORD pdw_LatchValue);									   
									
/** Tests the internal status of all the modules.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[out] pb_TestStatus Auto test returned value (0: no error, 1: error on counter 0, 2: error on counter 2, 3: error on counter 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : No counter module found
*/
_INT_   i_PCI1710_CounterAutoTest (HANDLE h_DeviceHandle,
					               PBYTE pb_TestStatus);

/** Deletes the counter value of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_ClearCounterValue (HANDLE h_DeviceHandle,
					                 BYTE b_ModuleNbr);

/** Deletes all the counter values.
*
* @param[in] h_DeviceHandle Handle of the board
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_ClearAllCounterValue (HANDLE h_DeviceHandle);

/** Latching of the current value of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_LatchReg Selection of the latch register (0: for the first latch register, 1: for the second latch register)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected latch register is wrong
*/
_INT_   i_PCI1710_LatchCounter (HANDLE h_DeviceHandle,
				                BYTE b_ModuleNbr,
				                BYTE b_LatchReg);

/** Reads the status of the selected latch register of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configurred (0 to 3)
* @param[in] b_LatchReg Selection of the latch register (0: for the first latch register, 1: for the second latch register)
* @param[out] pb_LatchStatus Latch register status (0: no latch, 1: a software latch was generated, 2: a hardware latch was generated, 3: a software latch and a hardware latch were generated)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected latch register is wrong
*/
_INT_   i_PCI1710_ReadLatchRegisterStatus (HANDLE h_DeviceHandle,
						                   BYTE b_ModuleNbr,
						                   BYTE b_LatchReg,
						                   PBYTE pb_LatchStatus);

/** Reads the value of the selected latch register of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_LatchReg Selection of the latch register (0: for the first latch register, 1: for the second latch register)
* @param[out] pdw_LatchValue Latch register value
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected latch register is wrong
*/
_INT_   i_PCI1710_ReadLatchRegisterValue (HANDLE h_DeviceHandle,
						                  BYTE b_ModuleNbr,
						                  BYTE b_LatchReg,
						                  PDWORD pdw_LatchValue);

/** Enables the latch interrupt of the selected module. Each hardware latched generates an interrupt.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -15 : An interrupt routine is not installed (see the i_PCI1710_SetBoardIntRoutine function)
*/
_INT_   i_PCI1710_EnableLatchInterrupt (HANDLE h_DeviceHandle,
					                    BYTE  b_ModuleNbr);

/** Disables the latch interrupt of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -15 : An interrupt routine is not installed (see the i_PCI1710_SetBoardIntRoutine function)
*/
_INT_   i_PCI1710_DisableLatchInterrupt (HANDLE h_DeviceHandle,
						                 BYTE b_ModuleNbr);

/** Latches a 16-bit counter from the selected module in the first register and returns the latched value.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_SelectedCounter Selection of the 16-bit counter (0 or 1)
* @param[out] pdw_CounterValue 16-bit counter value
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected 16-bit counter is wrong
*/
_INT_   i_PCI1710_Read16BitCounterValue (HANDLE h_DeviceHandle,
						                 BYTE b_ModuleNbr,
						                 BYTE b_SelectedCounter,
						                 PDWORD pdw_CounterValue);

/** Latches the 32-bit counter from the selected module in the first register and returns the latched value.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pdw_CounterValue 32-bit counter value
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_Read32BitCounterValue (HANDLE h_DeviceHandle,
						                 BYTE b_ModuleNbr,
						                 PDWORD pdw_CounterValue);

/** Writes the 16-bit value into a 16-bit counter of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_SelectedCounter Selection of the 16-bit counter (0 or 1)
* @param[in] dw_WriteValue 16-bit write value
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_Write16BitCounterValue (HANDLE h_DeviceHandle,
						                  BYTE b_ModuleNbr,
						                  BYTE b_SelectedCounter,
						                  DWORD dw_WriteValue);

/** Writes the 32-bit value into the counter of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] dw_WriteValue 32-bit write value
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_Write32BitCounterValue (HANDLE h_DeviceHandle,
						                  BYTE b_ModuleNbr,
						                  DWORD dw_WriteValue);

/** Initializes the index action for the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_ReferenceAction Determines if the reference for the index-transfer shall be reset or not (0: reference has not an importance, 1: reference shall be set for the index transfer)
* @param[in] b_IndexOperation Index operation mode (0: after an index signal (high level), the counter value is deleted (32-bit), 1: after an index signal (high level), the counter value (32-bit) is latched into the first latch register, 2: after an index signal (low level), the counter value is deleted (32-bit), 3: after an index signal (low level), the counter value (32-bit) is latched into the first latch register, 4: after an index signal (high level), the counter value (32-bit) is latched into the first latch register and then deleted (32-bit), 5: after an index signal (low level), the counter value (32-bit) is latched into the first latch register and then deleted (32-bit))
* @param[in] b_AutoMode Enables or disables the automatic index reset (0: disables, 1: enables)
* @param[in] b_InterruptEnable Enables or disables the interrupt (0: disables, 1: enables)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected reference action is wrong
* @retval -5 : The index operation parameter is wrong
* @retval -6 : The automatic mode parameter is wrong
* @retval -7 : The interrupt parameter is wrong
* @retval -8 : An interrupt routine is not installed (see the i_PCI1710_SetBoardIntRoutine function)
*/
_INT_   i_PCI1710_InitIndex (HANDLE h_DeviceHandle,
				             BYTE b_ModuleNbr,
				             BYTE b_ReferenceAction,
				             BYTE b_IndexOperation,
				             BYTE b_AutoMode,
				             BYTE b_InterruptEnable);

/** Enables the index actions.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The index has not been initialized (see the i_PCI1710_InitIndex function) (see the i_PCI1710_InitIndex function)
*/
_INT_   i_PCI1710_EnableIndex (HANDLE h_DeviceHandle,
				               BYTE b_ModuleNbr);

/** Disables the index actions.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The index has not been initialized (see the i_PCI1710_InitIndex function) (see the i_PCI1710_InitIndex function)
* @retval -5 : Flag error
*/
_INT_   i_PCI1710_DisableIndex (HANDLE h_DeviceHandle,
				                BYTE b_ModuleNbr);

/** Returns the index status.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_IndexStatus Index status (0: no index, 1: an index is determined)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The index has not been initialized (see the i_PCI1710_InitIndex function)
*/
_INT_   i_PCI1710_GetIndexStatus (HANDLE h_DeviceHandle,
					              BYTE b_ModuleNbr,
					              PBYTE pb_IndexStatus);

/** Determines the hardware source for the index and the reference logic.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_SourceSelection Source of the index and the reference logic (0: source 0 (index logic connected to the differential input C and reference logic to the 24 V input E), 1: source 1 (reference logic connected to the differential input C and index logic to the 24 V input E))
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The module is not a counter module
* @retval -4 : The source selection is wrong
*/
_INT_	i_PCI1710_SetIndexAndReferenceSource (HANDLE h_DeviceHandle,
						                      BYTE b_ModuleNbr,
						                      BYTE b_SourceSelection);

/** Initializes the reference that corresponds with the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_ReferenceLevel Reference level (0: if '0', reference initialized, 1: if '1', reference initialized)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The reference level is wrong
*/
_INT_   i_PCI1710_InitReference (HANDLE h_DeviceHandle,
					             BYTE b_ModuleNbr,
					             BYTE b_ReferenceLevel);

/** Returns the reference status.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_ReferenceStatus Reference status (0: no reference, 1: a reference was enabled)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The reference has not been initialized (See the i_PCI1710_InitReference function)
*/
_INT_   i_PCI1710_GetReferenceStatus (HANDLE h_DeviceHandle,
					                  BYTE b_ModuleNbr,
					                  PBYTE pb_ReferenceStatus);

/** Returns the UAS status.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_UASStatus UAS status (0: UAS is set on low, 1: UAS is set on high)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_GetUASStatus (HANDLE h_DeviceHandle,
				                BYTE b_ModuleNbr,
				                PBYTE pb_UASStatus);

/** Returns the CB status.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_CBStatus CB status (0: no counter overflow, 1: counter overflow)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_GetCBStatus  (HANDLE h_DeviceHandle,
				                BYTE b_ModuleNbr,
				                PBYTE pb_CBStatus);

/** Returns the CB status of the two 16-bit counters.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_CBStatusCounter0 CB status of the 16-bit counter 0
* @param[out] pb_CBStatusCounter1 CB status of the 16-bit counter 1
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_ 	i_PCI1710_Get16BitCBStatus (HANDLE h_DeviceHandle,
					                BYTE b_ModuleNbr,
					                PBYTE pb_CBStatusCounter0,
					                PBYTE pb_CBStatusCounter1);

/** Gets the UD status of the counter runout.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_UDStatus UD status (0: counter runout in the selected mode, 1: counter runout in the selected mode upwards)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_   i_PCI1710_GetUDStatus  (HANDLE h_DeviceHandle,
				                BYTE b_ModuleNbr,
				                PBYTE pb_UDStatus);

/** Returns the latched status of the counter runout, after an interrupt is generated.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[out] pb_UDStatus UD status (0: counter runout in the selected mode downwards, 1: counter runout in the selected mode upwards, 2: there is no index interrupt)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : An interrupt routine is not installed (see the i_PCI1710_SetBoardIntRoutine function)
*/
_INT_   i_PCI1710_GetInterruptUDLatchedStatus  (HANDLE h_DeviceHandle,
						                        BYTE b_ModuleNbr,
						                        PBYTE pb_UDStatus);

/** Initializes the external pulse level for the seected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] b_ExternalStrobe Selection of the external pulse (strobe) (0: external pulse A, 1: external pulse B)
* @param[in] b_ExternalStrobeLevel Level of the external pulse (0: external latch is generated at '0', 1: external latch is generated at '1' (standard configuration))
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The selected external pulse is wrong
* @retval -5 : The external pulse level is wrong
*/
_INT_	i_PCI1710_InitExternalStrobe	(HANDLE h_DeviceHandle,
					                     BYTE b_ModuleNbr,
					                     BYTE b_ExternalStrobe,
					                     BYTE b_ExternalStrobeLevel);

/** Sets the 32-bit compare value. An interrupt is generated as soon as the counter has reached the compare value.
* For the SC3x or higher use the i_PCIe1710_InitModuloCompareLogic function
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] dw_CompareValue 32-bit compare value
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : For SC3x module use i_PCI1710_InitModuloCompareLogic
*/
_INT_   i_PCI1710_InitCompareLogic     (HANDLE h_DeviceHandle,
					                    BYTE b_ModuleNbr,
					                    DWORD dw_CompareValue);

/** Allow to add a correction to the compare value after a certain number or event. (require the SC60 firmware)
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @param[in] dw_ModuloCompareEventValue 16-bit Number of event before applying the correction
* @param[in] dw_ModuloCompareCorrectionValue 16-bit correction to applied (signed value)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The module Firmware is not correct (Should be between SC60 and SC69)
* @retval -4 : The parameter us_ModuloCompareEventValue is incorrect (Should be between 2 and 655535)
* @retval -5 : The dw_ModuloCompareCorrectionValue parameter is incorrect (the value compare + Correction value > 65535 or 0 <)
* @retval -6 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -7 : The compare functionality has not been initialized (see the i_PCI1710_InitCompareLogic function)
*/
_INT_ i_PCI1710_ModuloCompareCorrection(HANDLE h_BoardHandle,
				   						BYTE b_ModuleNbr,
										DWORD dw_ModuloCompareEventValue,
										DWORD dw_ModuloCompareCorrectionValue);										
										
/** Enables the 32-bit compare logic. An interrupt is generated as soon as the counter has reached the compare value.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The compare logic has not been initialized (see the i_PCI1710_InitCompareLogic function)
* @retval -5 : An interrupt routine is not installed (see the i_PCI1710_SetBoardIntRoutine function)
*/
_INT_   i_PCI1710_EnableCompareLogic   (HANDLE h_DeviceHandle,
					                    BYTE b_ModuleNbr);

/** Disables the 32-bit compare logic.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
* @retval -4 : The compare logic has not been initialized (see the i_PCI1710_InitCompareLogic function)
*/
_INT_   i_PCI1710_DisableCompareLogic  (HANDLE h_DeviceHandle,
					                    BYTE b_ModuleNbr);

/** Sets the digital output of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_	i_PCI1710_SetDigitalChlOn (HANDLE h_DeviceHandle,
				                   BYTE b_ModuleNbr);

/** Resets the digital output of the selected module.
*
* @param[in] h_DeviceHandle Handle of the board
* @param[in] b_ModuleNbr Number of the module to be configured (0 to 3)
* @retval 0 : No error
* @retval -1 : The device handle parameter is wrong
* @retval -2 : The selected module number is wrong
* @retval -3 : The counter has not been initialized (see the i_PCI1710_InitCounter function)
*/
_INT_	i_PCI1710_SetDigitalChlOff (HANDLE h_DeviceHandle,
				                    BYTE b_ModuleNbr);

 /** Init frequency measurement
  *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Module to configure (0 to 3)
 * @param[in] b_PCIInputClock Bus clock selection
 * @param[in] b_TimingUnity Unit of the time base (0 to 2)
 *                          \li 0: ns
 *                          \li 1: us
 *                          \li 2: ms
 * @param[in] ul_TimingInterval Value of the time base.
 * @param[out] pul_RealTimingInterval Correct value of the time base
 *
 * @return 0 : No error \n
 *		  -1 : The device handle parameter is wrong \n
 *		  -2 : b_ModulNbr parameter is wrong, must be < 4 \n
 *		  -3 : Module version is wrong \n
 *		  -4 : Counter not initialized, see "i_PCI1710_InitCounter" function \n
 *        -5 : b_TimingUnity is wrong
 *        -6 : b_PCIInputClock parameter is wrong, must be 30, 33 or 40 \n
 *        -7 : ul_TimingInterval parameter is wrong \n
 *        -8 : Module version is wrong for 40 MHz version \n
 *        -9 : There is no 40 Mhz quartz available on the board
 **/
_INT_ i_PCI1710_InitFrequencyMeasurement(HANDLE h_DeviceHandle,
						                 BYTE   b_ModulNbr,
						                 BYTE   b_PCIInputClock,
						                 BYTE   b_TimingUnity,
						                 DWORD  ul_TimingInterval,
						                 PDWORD pul_RealTimingInterval);

/** Enable frequency measurement
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Module to configure (0 to 3)
 * @param[in] b_InterruptEnable Enables or disables the interrupt
 *                              \li 1 : Interrupt enabled
 *                              \li 0 : Interrupt enabled
 *  
 * @return 0 : No error \n
 *		  -1 : The device handle parameter is wrong \n
 *		  -2 : b_ModulNbr parameter is wrong, must be < 4 \n
 *		  -3 : b_InterruptEnable parameter is wrong \n
 *		  -4 : Module version is wrong \n
 *		  -5 : Counter not initialized, see "i_PCI1710_InitCounter" function \n
 *		  -6 : Frequency measurement not initialized, see "i_PCI1710_InitFrequencyMeasurement" function \n
 **/
_INT_ i_PCI1710_EnableFrequencyMeasurement(HANDLE h_DeviceHandle,
						                   BYTE b_ModulNbr,
						                   BYTE b_InterruptEnable);


/** Disable frequency measurement
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Module to configure (0 to 3)		
 * 
 * @return 0 : No error \n
 *		  -1 : The device handle parameter is wrong \n
 *		  -2 : b_ModulNbr parameter is wrong, must be < 4 \n
 **/ 
_INT_ i_PCI1710_DisableFrequencyMeasurement(HANDLE h_DeviceHandle, BYTE_ b_ModulNbr);

/** Read the frequency measurement
 * 
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Module to configure (0 to 3)
 * @param[out] pb_Status Returns the status of the frequency measurement.
 *                       \li 0: Counter cycle not started
 *                       \li 1: Counter cycle started
 *                       \li 2: Counter cycle stoped
 * @param[out] pb_UDStatus Status of the upward/downward counter.
 *                       <li>
 *                           <ul><li> 2 x 16 bit counter mode </li>
 *                               <ul><li>  First 16-bit counter </li>
 *                                   <ul><li> 0 : Downward counter cycle </li>
 *                                       <li> 1 : Upward counter cycle </li>
 *                                       <li> 2 : Downward counter cycle </li>
 *                                       <li> 3 : Upward counter cycle </li>
 *                                   </ul>
 *                               </ul>
 *                               <ul><li> Second 16-bit counter </li>
 *                                   <ul><li> 0 : Downward counter cycle </li>
 *                                       <li> 1 : Downward counter cycle </li>
 *                                       <li> 2 : Upward counter cycle </li>
 *                                       <li> 3 : Upward counter cycle </li>
 *                                   </ul>
 *                               </ul>
 *                           </ul>
 *                           <ul><li> 1 x 32 bit counter mode </li>
 *                               <ul><li> 0 : Downward counter cycle </li>
 *                                   <li> 1 : Not used </li>
 *                                   <li> 2 : Not used </li>
 *                                   <li> 3 : Upward counter cycle </li>
 *                               </ul>
 *                           </li>
 *                       </ul>
 *                           
 * @param[out] pdw_ReadValue Returns the number of increments within the time base.
 *
 * @return 0 : No error \n
 *		  -1 : The device handle parameter is wrong \n
 *		  -2 : b_ModulNbr parameter is wrong, must be < 4 \n
 *		  -3 : Module version is wrong \n
 *		  -4 : Counter not initialized, see "i_PCI1710_InitCounter" function \n
 *		  -5 : Frequency measurement not initialized, see "i_PCI1710_InitFrequencyMeasurement" function \n
 *		  -6 : Frequency measurement not enabled, see "i_PCI1710_EnableFrequencyMeasurement" function \n
 **/
_INT_ i_PCI1710_ReadFrequencyMeasurement(HANDLE h_DeviceHandle,
					                     BYTE   b_ModulNbr,
					                     PBYTE  pb_Status,
					                     PBYTE  pb_UDStatus,
					                     PDWORD pdw_ReadValue);
/* @} */

/** \addtogroup PULSE_ENCODER xPCI-1710 pulse encoder functions
* \ingroup PCI1710
* @{
 *
 */

/** Configure the pulse encoder operating mode selected via b_ModulNbr and b_PulseEncoderNbr.
 * The pulse encoder after each pulse decrements the counter value from 1.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure (0 to 3)
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 * @param[in] b_InputLevelSelection Input level selection (0 or 1)
 *					\li 0: Pulse encoder counts low edges
 *					\li 1: Pulse encoder counts high edges
 * @param[in] b_TriggerOutputAction Digital trigger output action
 * 					\li 0: No action
 * 					\li 1: Set the trigger output pulse to high
 * 					\li 2: Set the trigger output pulse to low
 * @param[in] dw_StartValue Pulse encoder start value (1 to 4294967295)
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The module is not a pulse encoder module or b_ModuleNbr is wrong
 * @retval -3 : Pulse encoder selection is wrong
 * @retval -4 : Input level selection is wrong
 * @retval -5 : Digital trigger output action selection is wrong
 * @retval -6 : Pulse encoder start value is wrong
 */
_INT_ i_PCI1710_InitPulseEncoder(HANDLE h_DeviceHandle,
								 BYTE_  b_ModuleNbr,
								 BYTE_  b_PulseEncoderNbr,
								 BYTE_  b_InputLevelSelection,
								 BYTE_  b_TriggerOutputAction,
								 DWORD_ dw_StartValue);

/** Enable the selected pulse encoder (b_PulseEncoderNbr) from selected module (b_ModuleNbr).
 * Each input pulse decrements the pulse encoder counter value from 1.
 * If you enable the interrupt (b_InterruptHandling), an interrupt is generated when the pulse encoder has run down.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure (0 to 3)
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 * @param[in] b_CycleSelection
 * 			\li APCI1710_SINGLE: If the counter is set on "0", the pulse encoder is stopped.
 * 			\li APCI1710_CONTINUOUS: Each time the counting value is set on "0", the pulse encoder load the start value after the next pulse.
 * 	@param[in] b_InterruptHandling Interrupt can be generated when the pulse encoder has run down.
 * 			\li APCI1710_DISABLE: Interrupt is disabled
 * 			\li APCI1710_ENABLE: Interrupt is enabled
 * 	@retval 0 : No error
 * 	@retval -1 : The device handle parameter is wrong
 * 	@retval -2 : The module is not a pulse encoder module
 * 	@retval -3 : Pulse encoder selection is wrong
 * 	@retval -4 : Pulse encoder is not initialized. See function "i_PCI1710_InitPulseEncoder"
 * 	@retval -5 : Cycle selection mode is wrong
 * 	@retval -6 : uc_InterruptHandling selection is wrong
 * 	@retval -7 : Interrupt routine is not installed. See "i_PCI1710_SetBoardIntRoutine" function
 */
_INT_ i_PCI1710_EnablePulseEncoder(HANDLE h_DeviceHandle,
								   BYTE_  b_ModuleNbr,
								   BYTE_  b_PulseEncoderNbr,
								   BYTE_  b_CycleSelection,
								   BYTE_  b_InterruptHandling);

/** Disable the selected pulse encoder (b_PulseEncoderNbr) from selected module (b_ModuleNbr).
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure (0 to 3)
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 *
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : The module is not a pulse encoder module
 * @retval -3 : Pulse encoder selection is wrong
 * @retval -4 : Pulse encoder not initialized. See "i_PCI1710_InitPulseEncoder" function
 */
_INT_ i_PCI1710_DisablePulseEncoder(HANDLE h_DeviceHandle,
					 	 	 	 	BYTE_  b_ModuleNbr,
					 	 	 	 	BYTE_  b_PulseEncoderNbr);

/** Reads the pulse encoder status from selected pulse encoder (b_PulseEncoderNbr) from selected module (b_ModulNbr)
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 * @param[out] pb_Status Pulse encoder status
 * 			\li 0: No overflow occurs
 * 			\li 1: Overflow occurs
 *
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Module selection is wrong
 * @retval -3 : Pulse encoder selection is wrong
 * @retval -4 : Pulse encoder not initialized. See "i_PCI1710_InitPulseEncoder" function
 */
_INT_ i_PCI1710_ReadPulseEncoderStatus(HANDLE h_DeviceHandle,
						 	 	 	   BYTE_  b_ModuleNbr,
						 	 	 	   BYTE_  b_PulseEncoderNbr,
						 	 	 	   PBYTE_ pb_Status);

/** Reads the pulse encoder value from selected pulse encoder (b_PulseEncoderNbr) from selected module (b_ModulNbr)
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 * @param[out] pdw_ReadValue Pulse encoder value
 *
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Module selection is wrong
 * @retval -3 : Pulse encoder selection is wrong
 * @retval -4 : Pulse encoder not initialized. See "i_PCI1710_InitPulseEncoder" function
 */
_INT_ i_PCI1710_ReadPulseEncoderValue(HANDLE  h_DeviceHandle,
						 	 	 	  BYTE_   b_ModuleNbr,
						 	 	 	  BYTE_   b_PulseEncoderNbr,
						 	 	 	  PDWORD_ pdw_ReadValue);

/** Writes a 32 bits value (dw_WriteValue) into the selected pulse encoder (b_PulseEncoderNbr) from selected module (b_ModulNbr)
 * This operation sets the new start pulse encoder value.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Module to configure
 * @param[in] b_PulseEncoderNbr Pulse encoder selection (0 to 3)
 * @param[in] dw_WriteValue 32-bit value to be written
 *
 * @retval 0 : No error
 * @retval -1 : The device handle parameter is wrong
 * @retval -2 : Module selection is wrong
 * @retval -3 : Pulse encoder selection is wrong
 * @retval -4 : Pulse encoder not initialized. See "i_PCI1710_InitPulseEncoder" function
 */
_INT_ i_PCI1710_WritePulseEncoderValue(HANDLE h_DeviceHandle,
						 	 	 	   BYTE_  b_ModuleNbr,
						 	 	 	   BYTE_  b_PulseEncoderNbr,
						 	 	 	   DWORD_ dw_WriteValue);
/* @} */

/** \addtogroup TTL_IO xPCI-1710 TTL IO management functions
* \ingroup PCI1710
* @{
 *
 */

 /*i_PCI1710_InitTTLIODirection*/
 /** Permits the configure on a given module the TTL I/O in input or output mode
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which to initailize TTL I/O (0 to 3)
 * @param[in] b_PortAMode Mode of the port A (0 -> input , 1 -> output )
 * @param[in] b_PortBMode Mode of the port B (0 -> input , 1 -> output )
 * @param[in] b_PortCMode Mode of the port C (0 -> input , 1 -> output )
 * @param[in] b_PortDMode Mode of the port D (0 -> input , 1 -> output )
 * @return    > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong port A mode  \n
 *			   -4 : Wrong port B mode \n
 *			   -5 : Wrong port C mode \n
 *			   -6 : Wrong port D mode \n
 *			   -7 : Error during the affectation of the modes
 **/
 _INT_ i_PCI1710_InitTTLIODirection(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_PortAMode,
									BYTE_ b_PortBMode,
									BYTE_ b_PortCMode,
									BYTE_ b_PortDMode);

 /*i_PCI1710_ReadTTLIOChannelValue*/
/** Read the status of a given TTL digital input on a given port and module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_PortNbr Number of the port in which the input is located \n
								  (Port A (PA) -> 0, PB -> 1, PC -> 2, PD -> 3)
 * @param[in] b_ChannelNbr Channel to be read (0 to 7)
 * @param[out] pb_Value Status of the channel
 * @return	> 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong TTL digital input port number \n
 *			   -4 : Wrong channel number \n
 *			   -5 : Error while reading
 **/
 _INT_ i_PCI1710_ReadTTLIOChannelValue(HANDLE h_DeviceHandle,
										BYTE_  b_ModuleNbr,
										BYTE_ b_PortNbr,
										BYTE_ b_ChannelNbr,
										PBYTE_ pb_Value);

 /*i_PCI1710_ReadTTLIOPortValue*/
/** Read the satus of the TTL digital inputs of a given port on a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_PortNbr Number of the port in which the input is located \n
								  (Port A (PA) -> 0, PB -> 1, PC -> 2, PD -> 3)
 * @param[out] pb_Value Status of the port
 * @return	> 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong TTL digital input port number \n
 *			   -4 : Error while reading
 **/
 _INT_ i_PCI1710_ReadTTLIOPortValue(HANDLE h_DeviceHandle,
									BYTE_  b_ModuleNbr,
									BYTE_ b_PortNbr,
									PBYTE_ pb_Value);

 /*i_PCI1710_ReadTTLIOAllPortValue*/
/** Read the satus of the TTL digital inputs of a given port on a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[out] pdw_Value Status of all the port of the module
 * @return	> 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while reading
 **/

 _INT_ i_PCI1710_ReadTTLIOAllPortValue(HANDLE h_DeviceHandle,
										BYTE_  b_ModuleNbr,
										PDWORD_ pdw_Value);

 /*i_PCI1710_SetTTLIOChlOn*/
/** Put one of the TTL output to one
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_ChannelNbr Output channel to put high \n
 *								  0 : PD0 \n
 *								  1 : PD1 \n
 *								  2 to 9 : PA0 to PA7 \n
 *								  10 to 17 : PB0 to PB7 \n
 *								  18 to 25 : PC0 to PC7
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : The selected channel is wrong \n
 *			   -4 : Error while setting the output
 **/
 _INT_ i_PCI1710_SetTTLIOChlOn(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr, BYTE_ b_ChannelNbr);

 /*i_PCI1710_SetTTLIOChlOff*/
/** Put one of the TTL output to zero
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_ChannelNbr Output channel to put low \n
 *								  0 : PD0 \n
 *								  1 : PD1 \n
 *								  2 to 9 : PA0 to PA7 \n
 *								  10 to 17 : PB0 to PB7 \n
 *								  18 to 25 : PC0 to PC7
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : The selected channel is wrong \n
 *			   -4 : Error while setting the output
 **/
 _INT_ i_PCI1710_SetTTLIOChlOff(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr, BYTE_ b_ChannelNbr);

 /*i_PCI1710_SetTTLIOChannelOn*/
/** Put one of the TTL output to one
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_PortNbr Number of the port of the channel \n
								  (0 -> I, 1 -> J, 2 -> A, 3 -> B, 4 -> C)
 * @param[in] b_ChannelNbr Output channel to put high (0 to 7). \n
								  For port I and J only output 0 is available
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong selected output port \n
 *			   -4 : The selected channel is wrong \n
 *			   -5 : Error while setting the output
 **/
 _INT_ i_PCI1710_SetTTLIOChannelOn(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_PortNbr,
									BYTE_ b_ChannelNbr);

 /*i_PCI1710_SetTTLIOChannelOff*/
/** Put one of the TTL output to zero
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the input is located (0 to 3)
 * @param[in] b_PortNbr Number of the port of the channel (0 to 3)\n
								  (0 -> I, 1 -> J, 2 -> A, 3 -> B, 4 -> C)
 * @param[in] b_ChannelNbr Output channel to put low (0 to 7). \n
								  For port I and J only output 0 is available
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong selected output port \n
 *			   -4 : The selected channel is wrong \n
 *			   -5 : Error while setting the output
 **/
 _INT_ i_PCI1710_SetTTLIOChannelOff(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_PortNbr,
									BYTE_ b_ChannelNbr);


 /* @} */

 /** \addtogroup 82x54 xPCI-1710 82c54 timer counter management functions
* \ingroup PCI1710
* @{
 *
 */

 /*i_PCI1710_InitTimer*/
/** Initialize the 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[in] b_TimerMode Mode in which the timer is to be initialized \n
 *	\htmlonly
 * <table align="center" border=1 cellspacing=0 cellpadding=3>
 * 	<tr>
 * 		<td><b>Mode</b>
 *		</td>
 * 		<td><b>Description</b>
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>0
 *		</td>
 * 		<td>Interrupt at the end of the counting process. <br/>
 *			At the beginning the output is low. At the end of the counting process the output is put high.
 *			Then it begins a new counting process at the end of which the output will be switched low, and so on.
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>1
 *		</td>
 * 		<td>Monoflop, retriggerable through hardware. <br/>
 *			This mode is the same as the first except that the GATE triggers the timer instead of enabling or disabling it.
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>2
 *		</td>
 * 		<td>Pulse generator. <br/>
 *			The output is set to high after the initialization. Then when the counter reaches 0 the output is set to low
 *			during one clock signal. The signal is then put high again and this cycle is repeated. <br/>
 *			Time calculation = (dw_ReloadValue + 2) x input clock.
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>3
 *		</td>
 * 		<td>Square-wave generator. <br/>
 *			This mode is similar to the mode 2 except that the output is not set to low for one clock signal.
 *			The counter is reloaded and the output stays to low until it has reached 0 again.
 *			This cycle is automatically repeated.
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>4
 *		</td>
 * 		<td>Strobe, Triggered through software. <br/>
 *			The signal is initialy put high. When the counter reaches 0 the output is set low for one clock period.
 *			The signal is then reset to high. The counting sequence is triggered when a new value is written in. <br/>
 *			When a new value is written in during a counting cycle, this value will be loaded at the next clock pulse.
 *		</td>
 * 	</tr>
 * 	<tr>
 * 		<td>5
 *		</td>
 * 		<td>Strobe, trigger through hardware (retriggerable). <br/>
 *			This mode is the same as the fourth except that the GATE is used to trigger the timer.
 *		</td>
 * 	</tr>
 * </table>
 \endhtmlonly
 * @param[in] dw_ReloadValue Reload value of the timer (0 to 4 294 967 295)
 * @param[in] b_InputClockSelection Select the clock to be used (0 -> PCI bus clock, 1 -> external clock, 2 -> internal 10MHz clock) \n
 * 									  For timer 0 only PCI bus clock and internal 10 MHz clock are available (0 and 2)
 * @param[in] b_InputClockLevel Level of the clock (0 -> active at low level, 1 -> active at high level (input iverted))
 * @param[in] b_OutputLevel Selection of the output clock level (0 -> active at low, 1 -> active at high (output inverted))
 * @param[in] b_HardwareGateLevel Selection of the hardware gate level (0 -> active at low (inverted), 1 -> active at high) \n
 *									  If the external gate is not used, must be set to 0.
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : Wrong timer mode \n
 *			   -5 : Wrong input clock \n
 *			   -6 : Wrong input clock level \n
 *			   -7 : Wrong output level \n
 *			   -8 : Wrong hardware gate level \n
 *			   -9 : An error occured during the initialization
 */
 _INT_ i_PCI1710_InitTimer(HANDLE h_DeviceHandle,
							BYTE_ b_ModuleNbr,
							BYTE_ b_TimerNbr,
							BYTE_ b_TimerMode,
							DWORD_ dw_ReloadValue,
							BYTE_ b_InputClockSelection,
							BYTE_ b_InputClockLevel,
							BYTE_ b_OutputLevel,
							BYTE_ b_HardwareGateLevel);


 /*i_PCI1710_EnableTimer*/
/** Enable and start the 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[in] b_InterruptEnable Enable interrupt flag (0 -> interrupt disabled, 1 -> interrupt enabled) \n
 * The mask given to the user interrupt routine is determinated as follow :
 * \htmlonly
 * <table align="center" border=1 cellspacing=0 cellpadding=3>
 * 	<tr>
 *		<td>Timer</td>
 *		<td>Mask</td>
 * 	</tr>
 * 	<tr>
 *		<td>0</td>
 *		<td>0000 0000 000<b>1</b> 0000</td>
 * 	</tr>
 * 	<tr>
 *		<td>1</td>
 *		<td>0000 0000 00<b>1</b>0 0000</td>
 * 	</tr>
 * 	<tr>
 *		<td>2</td>
 *		<td>0000 0000 0<b>1</b>00 0000</td>
 * 	</tr>
 * </table>
 \endhtmlonly
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : Wrong interrupt flag \n
 * 			   -5 : An error occured while starting the timer
 */
_INT_ i_PCI1710_EnableTimer(HANDLE h_DeviceHandle,
							BYTE_ b_ModuleNbr,
							BYTE_ b_TimerNbr,
							BYTE_ b_InterruptEnable);

 /*i_PCI1710_DisableTimer*/
/** Stop and release the 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occured while stopping the timer
 */
_INT_ i_PCI1710_DisableTimer(HANDLE h_DeviceHandle,
							BYTE_ b_ModuleNbr,
							BYTE_ b_TimerNbr);

 /*i_PCI1710_ReadTimerValue*/
/** Read the current value of a given 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[out] pdw_Value Value of the timer
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occured while reading the value
 */
_INT_ i_PCI1710_ReadTimerValue(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								BYTE_ b_TimerNbr,
								PDWORD_ pdw_Value);

 /*i_PCI1710_ReadAllTimerValue*/
/** Read the values of the three 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[out] pdw_Values Array containing the three current values of the timers (0 -> timer 0 etc) \n
 *								  The array must be allocated before to call this function.
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : An error occured while reading the values
 */
_INT_ i_PCI1710_ReadAllTimerValue(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									DWORD pdw_Values[3]);

 /*i_PCI1710_GetTimerOutputLevel*/
/** Return the output level of a given 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[out] pb_Value Level of the output (0 -> low, 1 -> high)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occured while reading the output level
 */
_INT_ i_PCI1710_GetTimerOutputLevel(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_TimerNbr,
									PBYTE_ pb_Value);
                                    
 /*i_PCI1710_GetTimerProgressStatus*/
/** Return the status of the timer value for a given 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[out] pb_Status Status of the timer (1 -> timer value is 0, 0 -> timer value differs from 0 (i.e. timer runs or is initialized))
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occured while reading the status
 */
_INT_ i_PCI1710_GetTimerProgressStatus(HANDLE h_DeviceHandle,
										BYTE_ b_ModuleNbr,
										BYTE_ b_TimerNbr,
										PBYTE_ pb_Status);
                                    
 /*i_PCI1710_GetTimerProgressStatusEx*/
/** Return the status of a given 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[out] pb_Status Status of the timer (0 -> stopped, 1 -> running)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occured while reading the status
 */
_INT_ i_PCI1710_GetTimerProgressStatusEx(HANDLE h_DeviceHandle,
										  BYTE_ b_ModuleNbr,
										  BYTE_ b_TimerNbr,
										  PBYTE_ pb_Status);


 /*i_PCI1710_WriteTimerValue*/
/** Write the value of a given 82c54 timer
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module in which the timer is located (0 to 3)
 * @param[in] b_TimerNbr Number of the timer (0 to 2)
 * @param[in] dw_Value value to be written
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong timer \n
 *			   -4 : An error occurend while writing the value
 */
_INT_ i_PCI1710_WriteTimerValue(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								BYTE_ b_TimerNbr,
								DWORD_ dw_Value);


/** @} */

 /** \addtogroup SSI xPCI-1710 SSI (Synchronous Serial Interface) management functions
* \ingroup PCI1710
* @{
 *
 */

 /*i_PCI1710_InitSSI*/
/** Initialise the SSI on a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ProfileLength Length in bits of the profile. The profile is the position length plus the
 *								turn counter length in bits (2 -> 32) \n
 *								NOTE: when using a single turn encoder and binary representation, this value must be incremented by one.
 * @param[in] b_PositionLength Length in bits of the position. \n
 * 								 This value represents the current position in the current turn. \n
 *								NOTE: when using a single turn encoder and binary representation, this value must be incremented by one.
 * @param[in] b_TurnCptLength Length in bits of the turn counter (b_PositionLength + b_TurnCptLength must not be bigger than b_ProfileLength). \n
 *								This arugment can be put to 0. In this case, the counter is in single turn mode, and b_positionLength must be
 *								equal to b_ProfileLength.
 * @param[in] b_PCIInputClock Frequency of the input clock (PCI1710_30MHZ -> 30 or PCI1710_33MHZ -> 33)
 *								 (see your PC's PCI clock in its manual)
 * @param[in] dw_OutputClock Output clock (229 -> 5 000 000 Hz for PCI1710_30MHZ or 252 -> 5 000 000 Hz for PCI1710_33MHZ)
 * @param[in] b_CountingMode Selection of the counting mode (0 -> No conversion is made (raw value is delivered), 1 -> A conversion is made from gray code to binary). \n
 *            If "0" is selected: A gray code value is delivered, if a gray code sensor is used. A binary value is delivered, if a binary code sensor is used.
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong profile length \n
 *			   -4 : Wrong position length \n
 *			   -5 : Wrong turn count length \n
 *			   -6 : Wrong PCI input clock \n
 *			   -7 : Wrong output clock \n
 *			   -8 : Wrong counting mode \n
 *			   -9 : Error while initializing SSI
 */
 _INT_ i_PCI1710_InitSSI(HANDLE h_DeviceHandle,
						BYTE_ b_ModuleNbr,
						BYTE_ b_ProfileLength,
						BYTE_ b_PositionLength,
						BYTE_ b_TurnCptLength,
						BYTE_ b_PCIInputClock,
						DWORD_ dw_OutputClock,
						BYTE b_CountingMode);

 /*i_PCI1710_InitSSIRawData*/
/** Initialise the SSI on a given module. The difference with the other initialization lies in the fact
 * that datas are not formated. So the read values will have their parity bit, turn count and position
 * will not be automatically separated and so on.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ProfileLength Length in bits of the profile (2 -> 48)
 * @param[in] b_PCIInputClock Frequency of the input clock (PCI1710_30MHZ -> 30 or PCI1710_33MHZ -> 33)
 *								 (see your PC's PCI clock in its manual)
 * @param[in] dw_OutputClock Output clock (229 -> 5 000 000 Hz for PCI1710_30MHZ or 252 -> 5 000 000 Hz for PCI1710_33MHZ)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong profile length \n
 *			   -4 : Wrong PCI input clock \n
 *			   -5 : Wrong output clock \n
 *			   -6 : Error while initializing SSI
 */
_INT_ i_PCI1710_InitSSIRawData(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								BYTE_ b_ProfileLength,
								BYTE_ b_PCIInputClock,
								DWORD_ dw_OutputClock);

/*i_PCI1710_Read1SSIValue*/
/** Read one value of a given SSI counter
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_SSINbr Number of the SSI counter (0 -> 2)
 * @param[out] pdw_Position Possition in the current turn
 * @param[out] pdw_Turn Current turn number
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong SSI counter number \n
 *			   -4 : Error while reading the value
 */
_INT_ i_PCI1710_Read1SSIValue(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								BYTE_ b_SSINbr,
								PDWORD_ pdw_Position,
								PDWORD_ pdw_Turn);

 /*i_PCI1710_Read1SSIRawDataValue*/
/** Read the raw value of a given SSI counter
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_SSINbr Number of the SSI counter (0 -> 2)
 * @param[out] pdw_ValueArray Array of raw data
 * @param[in] b_ArraySize Size of the array
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong SSI counter number \n
 *			   -4 : Error while reading the value
 */
_INT_ i_PCI1710_Read1SSIRawDataValue(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								BYTE_ b_SSINbr,
								PDWORD_ pdw_ValueArray,
								BYTE_ b_ArraySize);

/*i_PCI1710_ReadAllSSIValue*/
/** Read the values of all SSI counters on a given nodule
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] pdw_Position Possition in the current turn (at least 3 * sizeof(DWORD) must be allocated)
 * @param[out] pdw_Turn Current turn number (at least 3 * sizeof(DWORD) must be allocated)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while reading the values
 */
_INT_ i_PCI1710_ReadAllSSIValue(HANDLE h_DeviceHandle,
								BYTE_ b_ModuleNbr,
								DWORD_ pdw_Position[3],
								DWORD_ pdw_Turn[3]);

 /*i_PCI1710_ReadAllSSIRawDataValue*/
/** Read the raw values of all SSI counters on a given nodule
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] pdw_ValueArray Array of raw data
 * @param[in] b_ArraySize Size of the array
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while reading the value
 */
 _INT_ i_PCI1710_ReadAllSSIRawDataValue(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									PDWORD_ pdw_ValueArray,
									BYTE_ b_ArraySize);


 /*i_PCI1710_ReadSSI1DigitalInput*/
/** Read the selected digital input on a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_Channel Channel to be read (0 -> 2)
 * @param[in] pb_Status Status of the channel (0 -> not active, 1 -> active)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong channel \n
 *			   -4 : Error while reading the input
 */
_INT_ i_PCI1710_ReadSSI1DigitalInput(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_Channel,
									PBYTE_ pb_Status);

 /*i_PCI1710_ReadSSIAllDigitalInput*/
/** Read all the digital input of a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] pb_Status Mask of the channel status (0000 0XYZ -> bit Z: D0, Y -> D1, X -> D2)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while reading the inputs
 */
_INT_ i_PCI1710_ReadSSIAllDigitalInput(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									PBYTE_ pb_Status);

 /*i_PCI1710_SetSSIDigitalOutputOn*/
/** Switches on all the digital output of a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while writing outputs
 */
_INT_ i_PCI1710_SetSSIDigitalOutputOn(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr);

  /*i_PCI1710_SetSSIDigitalOutputOff*/
/** Switches off all the digital output of a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while writing outputs
 */
_INT_ i_PCI1710_SetSSIDigitalOutputOff(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr);

 /*i_PCI1710_StartSSIAcquisition*/
/** Start a SSI acquisition on a given module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while starting the acquisition \n
 */
_INT_ i_PCI1710_StartSSIAcquisition(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr);

 /*i_PCI1710_GetSSIAcquisitionStatus*/
/** Get the status of the acquisition
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] pb_Status Status of the acquisition (0 -> finished, 1 -> running)
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Error while reading the status \n
 */
_INT_ i_PCI1710_GetSSIAcquisitionStatus(HANDLE h_DeviceHandle, BYTE_ b_ModuleNbr, PBYTE_ pb_Status);

 /*i_PCI1710_GetSSIValue*/
/** Get the value of a given counter
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_SSINbr Number of the counter (0 to 2)
 * @param[out] pdw_Position Possition in the current turn
 * @param[out] pdw_Turn Current turn number
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong SSI counter number \n
 *			   -4 : Error while reading the value
 */
_INT_ i_PCI1710_GetSSIValue(HANDLE h_DeviceHandle,
							BYTE_ b_ModuleNbr,
							BYTE_ b_SSINbr,
							PDWORD_ pdw_Position,
							PDWORD_ pdw_Turn);

 /*i_PCI1710_GetSSIRawDataValue*/
/** Get the raw value of a given SSI counter
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_SSINbr Number of the counter (0 to 2)
 * @param[out] pdw_ValueArray Array of raw data
 * @param[in] b_ArraySize Size of the array
 * @return > 0 : Warning \n
 *              0 : No Error \n
 *             -1 : The device handle parameter is wrong \n
 *			   -2 : Wrong module number \n
 *			   -3 : Wrong SSI counter number \n
 *			   -4 : Error while reading the value
 */
_INT_ i_PCI1710_GetSSIRawDataValue(HANDLE h_DeviceHandle,
									BYTE_ b_ModuleNbr,
									BYTE_ b_SSINbr,
									PDWORD_ pdw_ValueArray,
									BYTE_ b_ArraySize);

/** @} */


/** \addtogroup ETM xPCI-1710 Edge Time Measurement functions
 * \ingroup PCI1710
 * @{
 *
 */

/* i_PCI1710_InitETM */
/** Configures all ETM counters of the selected module.
 * The parameters dw_Timing und dw_TimingUnit determine the time base for the measurement.
 * pdw_RealTiming returns the correct time value.
 * Call this function before you call another function that accesses the ETM counter.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ClockSelection Selection of the reference clock (30: PCI clock (30 MHz), 33: PCI clock (33 MHz), 40: 40 MHz onboard quartz)
 * @param[in] b_TimingUnit Unit of the time base (0: ns 1: us 2: ms)
 * @param[in] dw_Timing Value of the time base
 * @param[out] pdw_RealTiming Correct value of the time base. Returns the value that corresponds best with the value entered in the dw_Timing
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected input clock is wrong
 * @retval -5 The selected time unit is wrong
 * @retval -6 The selected time base is wrong
 * @retval -7 The 40 MHz cannot be configured on your board
 */
_INT_ i_PCI1710_InitETM(HANDLE h_DeviceHandle,
                        BYTE_ b_ModuleNbr,
                        BYTE_ b_ClockSelection,
                        BYTE_ b_TimingUnit,
                        DWORD_ dw_Timing,
                        PDWORD_ pdw_RealTiming);

/* i_PCI1710_EnableETM */
/** Enables the ETM counter of the selected module.
 * The function "i_PCI1710_InitETM" has to be called first.
 * If the interrupt is enabled, the ETM counter generates an interrupt after each trigger signal.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[in] b_EdgeLevel Edge selection for time measurement (0: Measures the low level time, 1: Measures the high level time)
 * @param[in] b_TriggerLevel Selection of the trigger level (0: Trigger at low level, 1: Trigger at high level)
 * @param[in] b_CycleMode Mode selection (0: Single mode, 1: Continuous Mode). Each trigger stops the measurement and starts a new cycle.
 * @param[in] b_FirstTriggerMode Mode of the first trigger 0: The measurement of the first edge time starts after calling the function "i_PCI1710_EnableETM". 1: The measurement of the first edge time starts after the next trigger signal.
 * @param[in] b_InterruptEnable Enables or disables the interrupt function. (0: interrupts disabled, 1: interrupts enabled)
 * @retval  0  No error
 * @retval -1  The handle parameter of the board is wrong
 * @retval -2  The selected module number is wrong
 * @retval -3  The selected module is not an ETM module
 * @retval -4  The selected ETM counter is wrong
 * @retval -5  ETM is not initialised. See function "i_PCI1710_InitETM"
 * @retval -6  Selection of the edge level is wrong
 * @retval -7  Selection of the trigger level is wrong
 * @retval -8  Mode selection is wrong
 * @retval -9  Mode selection for the first trigger is wrong
 * @retval -10 Interrupt parameter is wrong
 * @retval -11 Interrupt function is not initialised
 */
_INT_ i_PCI1710_EnableETM(HANDLE h_DeviceHandle,
                          BYTE_ b_ModuleNbr,
                          BYTE_ b_ETM,
                          BYTE_ b_EdgeLevel,
                          BYTE_ b_TriggerLevel,
                          BYTE_ b_CycleMode,
                          BYTE_ b_FirstTriggerMode,
                          BYTE_ b_InterruptEnable);

/* i_PCI1710_DisableETM */
/** Disables the ETM counter of the selected module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 */
_INT_ i_PCI1710_DisableETM(HANDLE h_DeviceHandle,
                           BYTE_ b_ModuleNbr,
                           BYTE_ b_ETM);

/* i_PCI1710_GetETMInitialisation */
/** Returns the information about the ETM initialisation for the selected module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[out] pb_TimingUnit Unit of the time base (0: ns, 1: us, 2: ms)
 * @param[out] pdw_Timing Value of the time base.
 * @param[out] pb_EdgeLevel Edge selection for time measurement (0: Measures the low level time, 1: Measures the high level time)
 * @param[out] pb_TriggerLevel Selection of the trigger level (0: Trigger at the low level, 1: Trigger at the high level)
 * @param[out] pb_CycleMode Mode selection (0: Single mode, 1: Continuous mode). Each trigger stops the measurement and starts a new cycle
 * @param[out] pb_FirstTriggerMode Mode of the first trigger (0: The measurement of the first edge time starts after calling the function "i_PCI1710_EnableETM", 1: The measurement of the first edge time starts after the next trigger signal).
 * @param[out] pb_InterruptEnable Enables or disables the interrupt function. (0: interrupts disabled, 1: interrupts enabled)
 * @param[out] pb_Enable Returns whether the ETM is enabled or disabled. (0: ETM disabled, 1: ETM enabled)
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 */
_INT_ i_PCI1710_GetETMInitialisation(HANDLE h_DeviceHandle,
                                     BYTE_ b_ModuleNbr,
                                     BYTE_ b_ETM,
                                     PBYTE_ pb_TimingUnit,
                                     PDWORD_ pdw_Timing,
                                     PBYTE_ pb_EdgeLevel,
                                     PBYTE_ pb_TriggerLevel,
                                     PBYTE_ pb_CycleMode,
                                     PBYTE_ pb_FirstTriggerMode,
                                     PBYTE_ pb_InterruptEnable,
                                     PBYTE_ pb_Enable);

/* i_PCI1710_GetETMProgressStatus */
/** Returns the ETM state of the selected module
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[out] pb_ETMStatus The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: An overflow occurred)
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 */
_INT_ i_PCI1710_GetETMProgressStatus(HANDLE h_DeviceHandle,
                                     BYTE_ b_ModuleNbr,
                                     BYTE_ b_ETM,
                                     PBYTE_ pb_ETMStatus);

/* i_PCI1710_ReadETMValue */
/** Returns the ETM state and the time value after a stop signal on the selected module.
 * This function is only available when you disable the interrupt function.
 * The returned value is not the actual measured time value. You must use the function "i_PCI1710_ConvertETMValue" or apply the following formula in order to calculate the time value:
 *   Time value = pdw_ETMValue x pdw_RealTiming
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[in] dw_TimeOut Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)
 * @param[out] pb_ETMStatus The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: An overflow occurred, 4: Timeout reached)
 * @param[out] pdw_ETMValue ETM time value.
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 * @retval -6 The timeout parameter is wrong (0 to 65535)
 * @retval -7 Interrupt routine installed; the measured ETM cannot be read directly
 */
_INT_ i_PCI1710_ReadETMValue(HANDLE h_DeviceHandle,
                             BYTE_ b_ModuleNbr,
                             BYTE_ b_ETM,
                             DWORD_ dw_TimeOut,
                             PBYTE_ pb_ETMStatus,
                             PDWORD_ pdw_ETMValue);

/* i_PCI1710_ReadETMTotalTime */
/** Returns the ETM status and the total time value after a stop signal occurred on the selected ETM module.
 * This function is only available if you have disabled the interrupt function.
 * The returned value is not the actual measured time value. You must use the function "i_PCI1710_ConvertETMValue" or apply the following formula in order to calculate the time value:
 *   pdw_ETMValue x pdw_RealTiming
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[in] dw_TimeOut Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)
 * @param[out] pb_ETMStatus The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: An overflow occurred, 4: Timeout reached)
 * @param[out] pdw_ETMValue ETM time value.
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 * @retval -6 The timeout parameter is wrong (0 to 65535)
 * @retval -7 Interrupt routine installed; the measured ETM cannot be read directly
 */ 
_INT_ i_PCI1710_ReadETMTotalTime(HANDLE h_DeviceHandle,
                                 BYTE_ b_ModuleNbr,
                                 BYTE_ b_ETM,
                                 DWORD_ dw_TimeOut,
                                 PBYTE_ pb_ETMStatus,
                                 PDWORD_ pdw_ETMValue);

/* i_PCI1710_ReadETMDutyCycleValue */
/** Returns the ETM status and the duty cycle value after a stop signal occurred on the selected ETM module.
 * This function is only available if you have disabled the interrupt function.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_ETM Selection of the ETM counter (0 or 1)
 * @param[in] dw_TimeOut Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)
 * @param[out] pb_ETMStatus The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: An overflow occurred, 4: Timeout reached)
 * @param[out] pd_DutyCycle ETM duty cycle.
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 The selected ETM counter is wrong
 * @retval -5 ETM is not initialised. See function "i_PCI1710_InitETM"
 * @retval -6 The timeout parameter is wrong (0 to 65535)
 * @retval -7 Interrupt routine installed; the measured ETM cannot be read directly
 */ 
_INT_ i_PCI1710_ReadETMDutyCycleValue(HANDLE h_DeviceHandle,
                                      BYTE_ b_ModuleNbr,
                                      BYTE_ b_ETM,
                                      DWORD_ dw_TimeOut,
                                      PBYTE_ pb_ETMStatus,
                                      PDOUBLE pd_DutyCycle);

/* i_PCI1710_ConvertETMValue */
/** Converts the measured ETM time in hours, minutes, seconds, milliseconds, microseconds and nanoseconds.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] dw_ETMValue ETM time value. See "i_PCI1710_ReadETMValue"
 * @param[out] pdw_Hour Time measurement in hours
 * @param[out] pb_Minute Time measurement in minutes
 * @param[out] pb_Second Time measurement in seconds
 * @param[out] pdw_MilliSecond Time measurement in milliseconds
 * @param[out] pdw_MicroSecond Time measurement in microseconds
 * @param[out] pdw_NanoSecond Time measurement in nanoseconds
 * @retval  0 No error
 * @retval -1 The handle parameter of the board is wrong
 * @retval -2 The selected module number is wrong
 * @retval -3 The selected module is not an ETM module
 * @retval -4 ETM is not initialised. See function "i_PCI1710_InitETM"
 */ 
_INT_ i_PCI1710_ConvertETMValue(HANDLE h_DeviceHandle,
                                BYTE_ b_ModuleNbr,
                                DWORD_ dw_ETMValue,
                                PDWORD_ pdw_Hour,
                                PBYTE_ pb_Minute,
                                PBYTE_ pb_Second,
                                PDWORD_ pdw_MilliSecond,
                                PDWORD_ pdw_MicroSecond,
                                PDWORD_ pdw_NanoSecond);

/** @} */


/**
 *		\addtogroup PWM xPCI-1710 PWM functions
 * 		\ingroup PCI1710
 *		@{
 */

/** Initializes the PWM. \n
 *
 * This function configures the selected PWM from the selected module.
 * The ul_LowTiming, ul_HighTiming and b_TimingUnit determine the low/high base timing for the persiod.
 * The pul_RealLowTiming and pul_RealHighTiming return the real timing value.
 * You must call this function before calling any other PWM function.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Index of the module to configure (0 to 3)
 * @param[in] b_PWM Index of the selected PWM (0 or 1)
 * @param[in] b_TimingUnit Timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)
 * @param[in] ul_LowTiming Low base timing value
 * @param[in] ul_HighTiming High base timing value
 * @param[out] pul_RealLowTiming Real low base timing value
 * @param[out] pul_RealHighTiming Real high base timing value
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    The base timing value is wrong
 * @retval -5    The low base timing selection is wrong
 * @retval -6    The high base timing selection is wrong
 * @retval -7    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - Invalid timing unit
 * @retval -104  Driver - Invalid low timing
 * @retval -105  Driver - Invalid high timing
 * @retval -106  Driver - The module selected is not a PWM module
 */
_INT_ i_PCI1710_InitPWM(HANDLE h_DeviceHandle,
                         BYTE b_ModulNbr,
  	                     BYTE b_PWM,
                         BYTE b_TimingUnit,
                         ULONG ul_LowTiming,
                         ULONG ul_HighTiming,
                         PULONG pul_RealLowTiming,
                         PULONG pul_RealHighTiming);

 /** Sets a new timing. \n
 *
 * The ul_LowTiming, ul_HighTiming and b_TimingUnit determine the low/high base timing for the persiod.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_PWM Selected PWM (0 or 1)
 * @param[in] b_TimingUnit Timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)
 * @param[in] ul_LowTiming Low base timing value
 * @param[in] ul_HighTiming High base timing value
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    The base timing value is wrong
 * @retval -5    The low base timing selection is wrong
 * @retval -6    The high base timing selection is wrong
 * @retval -7    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - Invalid timing unit
 * @retval -104  Driver - Invalid low timing
 * @retval -105  Driver - Invalid high timing
 * @retval -106  Driver - The module selected is not a PWM module
 * @retval -107  Driver - The PWM has not been initialized
 */
_INT_ i_PCI1710_SetNewPWMTiming(HANDLE h_DeviceHandle,
                                 BYTE b_ModulNbr,
  	                             BYTE b_PWM,
                                 BYTE b_TimingUnit,
                                 ULONG ul_LowTiming,
                                 ULONG ul_HighTiming);

 /** Enables the selected PWM of the selected module. \n
 *
 * The i_PCI1710_InitPWM function must be called before calling this function.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_PWM Selected PWM (0 or 1)
 * @param[in] b_StartLevel Start period level selection (0: the period will start with a low level, 1: the period will start with a high level)
 * @param[in] b_StopMode Stop mode selection (0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function, 1: the PWM will be stopped after the end of the last period after the call of the disable function)
 * @param[in] b_StopLevel Stop PWM level selection (0: the output signal will keep its level after the call of the i_PCI1710_DisablePWM function, 1: the output signal will be set to low after the call of the disable function, 2: the output signal will be set to high after the call of the disable function)
 * @param[in] b_ExternGate Extern gate action selection (0: extern gate signal not used, 1: extern gate signal used)
 * @param[in] b_InterruptEnable Enable or disable the interrupt (0: disable the PWM interrupt, 1: an interrupt will occur after each end of state)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    The PWM start level selection is wrong
 * @retval -5    The PWM stop mode selection is wrong
 * @retval -6    The PWM stop level selection is wrong
 * @retval -7    The extern gate signal selection is wrong
 * @retval -8    The interrupt parameter is wrong
 * @retval -9    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - Invalid start level selection
 * @retval -104  Driver - Invalid stop mode selection
 * @retval -105  Driver - Invalid stop level selection
 * @retval -106  Driver - Invalid extern gate selection
 * @retval -107  Driver - Invalid interrupt flag selection
 * @retval -108  Driver - The module selected is not PWM module
 * @retval -109  Driver - The PWM has not been initialized
 */
_INT_ i_PCI1710_EnablePWM(HANDLE h_DeviceHandle,
                           BYTE b_ModulNbr,
  	                       BYTE b_PWM,
                           BYTE b_StartLevel,
                           BYTE b_StopMode,
                           BYTE b_StopLevel,
                           BYTE b_ExternGate,
                           BYTE b_InterruptEnable);

 /** Disables the selected PWM of the selected module. \n
 *
 * The output signal level depends of the configuration of the PWM parameter (see the b_StartLevel, b_StopMode and b_StopLevel parameters of the i_PCI1710_EnablePWM function).
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_PWM Selected PWM (0 or 1)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - The module selected is not a PWM module
 * @retval -104  Driver - The PWM has not been initialized
 * @retval -105  Driver - The PWM has not been enabled
 */
_INT_ i_PCI1710_DisablePWM(HANDLE h_DeviceHandle,
                            BYTE b_ModulNbr,
  	                        BYTE b_PWM);

 /** Returns the selected PWM initialization of the selected module. \n
 *
 * The i_PCI1710_InitPWM function must be called before calling this function.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_PWM Selected PWM (0 or 1)
 * @param[out] pb_TimingUnit Returns the base timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)
 * @param[out] pul_LowTiming Returns the low base timing value
 * @param[out] pul_HighTiming Returns the high base timing value
 * @param[out] pb_StartLevel Returns the start period level selection (0: the period will start with a low level, 1: the period will start with a high level)
 * @param[out] pb_StopMode Returns the stop mode selection(0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function and will break the last period, 1: the PWM will end its last period before being stopped after the call of the disable function)
 * @param[out] pb_StopLevel Returns the stop level selection (0: the output signal will keep the level after the call of the i_PCI1710_DisablePWM function, 1: the output signal will be stopped at low after the call of the disable function, 2: the output signal will be set to high after the call of the disable function)
 * @param[out] pb_ExternGate Indicates if the extern gate action is used (0: not used, 1: used)
 * @param[out] pb_InterruptEnable Indicates if the interrupt are enabled or not (0: disabled, 1: enabled)
 * @param[out] pb_Enable Indicates if the PWM is enabled or not (0: disabled, 1: enabled)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - The module selected is not a PWM module
 * @retval -104  Driver - The PWM has not been initialized
 * @retval -105  Driver - The PWM has not been enabled
 */
_INT_ i_PCI1710_GetPWMInitialisation(HANDLE h_DeviceHandle,
                                      BYTE b_ModulNbr,
  	                                  BYTE b_PWM,
                                      PBYTE pb_TimingUnit,
                                      PULONG pul_LowTiming,
                                      PULONG pul_HighTiming,
                                      PBYTE pb_StartLevel,
                                      PBYTE pb_StopMode,
                                      PBYTE pb_StopLevel,
                                      PBYTE pb_ExternGate,
                                      PBYTE pb_InterruptEnable,
                                      PBYTE pb_Enable);

 /** Returns the selected PWM status of the selected module. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_PWM Selected PWM (0 or 1)
 * @param[out] pb_PWMOutputStatus Returns the PWM output level status (0: low or 1: high)
 * @param[out] pb_ExternGateStatus Returns the extern gate level status (0: low or 1: high)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The PWM selection is wrong
 * @retval -4    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - Invalid PWM index
 * @retval -103  Driver - The module selected is not a PWM module
 * @retval -104  Driver - The PWM has not been initialized
 * @retval -105  Driver - The PWM has not been enabled
 */
_INT_ i_PCI1710_GetPWMStatus(HANDLE h_DeviceHandle,
                              BYTE b_ModulNbr,
  	                          BYTE b_PWM,
                              PBYTE pb_PWMOutputStatus,
                              PBYTE pb_ExternGateStatus);

/** Reads the status of the selected PWM digital input of the selected module. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_InputChannel Selected digital input (0 to 2)
 * @param[out] pb_ChannelStatus Returns the digital inptut channel status (0: reset or 1: set)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The selected digital input is wrong
 * @retval -4    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - The module selected is not a PWM module
 */
_INT_ i_PCI1710_ReadPWM1DigitalInput(HANDLE h_DeviceHandle,
                                      BYTE b_ModulNbr,
 	                                  BYTE b_InputChannel,
 	                                  PBYTE pb_ChannelStatus);

/** Reads the status of all the PWM digital inputs of the selected module. \n
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[out] pb_InputStatus Digital inputs channel status
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - The module selected is not a PWM
 */
_INT_ i_PCI1710_ReadPWMAllDigitalInputs(HANDLE h_DeviceHandle,
                                         BYTE b_ModulNbr,
 	                                     PBYTE pb_InputStatus);

/** Enables or disables to set manually the digital output H of the selected module. \n
 *
 * When the PWM 0 will be enabled for the first time, the digital output manual setting will be considered as disabled, which means that it would the PWM 0 which will control the digital output of the selected module.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 * @param[in] b_Flag Enable/disable flag (0: disable the manual setting, the output H is controlled parallely to the PWM0, or 1: enable the manual setting, the output H will be set via the i_PCI1710_SetPWMDigitalOutputOn function or reset via the i_PCI1710_SetPWMDigitalOutputOff function)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    The flag parameter is wrong
 * @retval -4    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - The module selected is not a PWM
 */
_INT_ i_PCI1710_EnableDisablePWMDigitalOutputManualSetting(HANDLE h_DeviceHandle,
                                                            BYTE b_ModulNbr,
 	                                                        BYTE b_Flag);

/** Sets on the digital output H of the selected PWM of the selected module. \n
 *
 * The i_PCI1710_EnableDisablePWMDigitalOutputSetting function must be called before calling this function
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - The module selected is not a PWM
 * @retval -103  Driver - The manual setting option is not active
 */
_INT_ i_PCI1710_SetPWMDigitalOutputOn(HANDLE h_DeviceHandle,
                                       BYTE b_ModulNbr);

/** Sets off the digital output H of the selected PWM of the selected module. \n
 *
 * The i_PCI1710_EnableDisablePWMDigitalOutputSetting function must be called before calling this function
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModulNbr Number of the module to configure (0 to 3)
 *
 * @retval  0    No Error
 * @retval -1    The device handle parameter is wrong
 * @retval -2    The module selection is wrong
 * @retval -3    Error while calling IOCTL function
 * @retval -101  Driver - Invalid module index
 * @retval -102  Driver - The module selected is not a PWM
 * @retval -103  Driver - The manual setting option is not active
 */
_INT_ i_PCI1710_SetPWMDigitalOutputOff(HANDLE h_DeviceHandle,
                                        BYTE b_ModulNbr);


/* @} */


/** \addtogroup DIG_IO xPCI-1710 Digital Inputs/Outputs functions
 * \ingroup PCI1710
 * @{
 *
 */

/** Get the value of the digital inputs \n
 * There can be 5 to 7 inputs (A to G, with A and B configurable as inputs or outputs) \n
 * The output value pb_DigitalInputs is a 7-bits value, which represent the following inputs :
 * <ul>
 *	<li>Bit 0: Input C</li>
 *	<li>Bit 1: Input D</li>
 *	<li>Bit 2: Input E (Inverted)</li>
 *	<li>Bit 3: Input F (Inverted)</li>
 *	<li>Bit 4: Input G (Inverted)</li>
 *	<li>Bit 5: Input A (0 if A is set as Output)</li>
 *	<li>Bit 6: Input B (0 if B is set as Output)</li>
 * </ul>
 * For further information regarding pin assignement and input types, please refer to the manual
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] pb_DigitalInputs Value of the inputs (0x0 to 0x7F)
 *
 * @return	 0 : No Error \n
 *			-1 : The device handle parameter is wrong \n
 *			-2 : Wrong module number \n
 *			-3 : The digital port has not been configured \n
 *			-4 : Error while reading the value
 */
_INT_ i_PCI1710_ReadDigitalInputs(
	HANDLE	h_DeviceHandle,
	BYTE_	b_ModuleNbr,
	PBYTE_	pb_DigitalInputs);


/** Set the value of the digital outputs \n
 * If digital output memory is OFF, the outputs which are not covered by the mask b_DigitalOutputs are reset. Else, they can only be reset by calling i_PCI1710_SetDigitalOutputsOff. \n
 * There can be 1 to 3 outputs (A, B and H, with A and B configurable as inputs or outputs) \n
 * The value b_DigitalOutputs is a 3-bits value, which represent the following outputs :
 * <ul>
 *	<li>Bit 0: Output H</li>
 *	<li>Bit 1: Output A (not used if A is set as Input)</li>
 *	<li>Bit 2: Output B (not used if B is set as Input)</li>
 * </ul>
 * For further information regarding pin assignement and input types, please refer to the manual
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] b_DigitalOutputs Value of the outputs (0x0 to 0x7)
 *
 * @return	 0 : No Error \n
 *			-1 : The device handle parameter is wrong \n
 *			-2 : Wrong module number \n
 *			-3 : The digital port has not been configured \n
 *			-4 : Error while reading the value
 */
_INT_ i_PCI1710_SetDigitalOutputsOn(
	HANDLE	h_DeviceHandle,
	BYTE_	b_ModuleNbr,
	BYTE_	b_DigitalOutputs);


/** Reset the digital outputs \n
 * This function only works if the digital output memory is ON. Otherwise, it returns an error. \n
 * There can be 1 to 3 outputs (A, B and H, with A and B configurable as inputs or outputs) \n
 * The value b_DigitalOutputs is a 3-bits value, which represent the following outputs :
 * <ul>
 *	<li>Bit 0: Output H</li>
 *	<li>Bit 1: Output A (not used if A is set as Input)</li>
 *	<li>Bit 2: Output B (not used if B is set as Input)</li>
 * </ul>
 * For further information regarding pin assignement and input types, please refer to the manual
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[out] b_DigitalOutputs Value of the outputs (0x0 to 0x7)
 *
 * @return	 0 : No Error \n
 *			-1 : The device handle parameter is wrong \n
 *			-2 : Wrong module number \n
 *			-3 : The digital port has not been configured \n
 *			-4 : The digital output memory is off \n
 *			-4 : Error while setting the value
 */
_INT_ i_PCI1710_SetDigitalOutputsOff(
	HANDLE	h_DeviceHandle,
	BYTE_	b_ModuleNbr,
	BYTE_	b_DigitalOutputs);

/** Set the mode of the digital inputs/outputs A and B \n
 * This function must be called before any other digital function \n
 * For further information regarding pin assignement and input types, please refer to the manual
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_ModuleNbr Number of the module (0 to 3)
 * @param[in] b_PortAMode Mode of pin A (PCI1710_PORT_INPUT or PCI1710_PORT_OUTPUT)
 * @param[in] b_PortBMode Mode of pin B (PCI1710_PORT_INPUT or PCI1710_PORT_OUTPUT)
 *
 * @return	 0 : No Error \n
 *			-1 : The device handle parameter is wrong \n
 *			-2 : Wrong module number \n
 *			-3 : Port A mode is invalid \n
 *			-4 : Port B mode is invalid \n
 *			-5 : Error while setting the mode
 */
_INT_ i_PCI1710_SetPortConfiguration(
	HANDLE	h_DeviceHandle,
	BYTE_	b_ModuleNbr,
	BYTE_	b_PortAMode,
	BYTE_	b_PortBMode );


/** Set the digital output memory ON or OFF according to b_DOMOnOff : \n
 * \li PCI1710_ENABLE: When setting the outputs, all outputs not covered by the mask stay set. They have to be reset by a call to i_PCI1710_SetDigitalOutputsOff.
 * \li PCI1710_DISABLE: When setting the outputs, all outputs not covered by the mask are reset. Calls to i_PCI1710_SetDigitalOutputsOff will return an error.
 *
 * @param[in] h_DeviceHandle Handle of the board
 * @param[in] b_DOMOnOff Digital output memory mode (PCI1710_ENABLE or PCI1710_DISABLE)
 *
 * @return	 0 : No Error \n
 *			-1 : The device handle parameter is wrong \n
 *			-2 : Wrong DOM mode parameter \n
 */
_INT_ i_PCI1710_SetDigitalOutputMemory (
	HANDLE	h_DeviceHandle,
	BYTE_	b_DOMOnOff );
	
/** @} */

/** @} */
 
#ifdef __cplusplus
	}
#endif
