//##protect##"FileHeader"
/** @file PCI1710.cs
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 18.02.2013
 *  @date    $LastChangedDate$
 *  @version $LastChangedRevision$
 *
 *  @par DESCRIPTION
 *  PCI1710 .NET interface functions 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2013 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace PCI1710_NET
{
#region "User declarations"
//##protect##"UserDeclarations"
//##protect##"UserDeclarations"
#endregion

    public class PCI1710
    {
        private int index;
        private IntPtr handle;

		private DllImport.InterruptFunctionEventHandler interruptFunctionHandler;

#region "Event Args and Handlers"
        private InterruptEventArgs interruptEventArgs;
        public delegate void InterruptEventHandler(object source, InterruptEventArgs eventArgs);
        public event InterruptEventHandler InterruptEventReceived;

//##protect##"EventArgsAndHandlersDeclaration"
//##protect##"EventArgsAndHandlersDeclaration"
#endregion
#region "Constructor/Destructor"
        /// <summary>
        /// Class constructor
        /// </summary>
        private PCI1710()
        {
            this.index = -1;
            this.handle = IntPtr.Zero;

            // Create the event args (once by board)
            this.interruptEventArgs = new InterruptEventArgs();

            // Create the interrupt handler (once by board)
            this.interruptFunctionHandler = new DllImport.InterruptFunctionEventHandler(InterruptFunction);

            // Tell the garbage collector to keep the pointer
            GC.KeepAlive(this.interruptFunctionHandler);

//##protect##"Constructor"
//##protect##"Constructor"
        }

        /// <summary>
        /// Class destructor
        /// </summary>
        ~PCI1710()
        {
            DllImport.i_PCI1710_CloseBoard(this.handle);
            this.index = -1;
            this.handle = IntPtr.Zero;

//##protect##"Destructor"
//##protect##"Destructor"
        }
#endregion
#region "Utils"
        /// <summary>
        /// Creates an instance of a PCI1710 board
        /// </summary>
        /// <param name="index">The index of the board you want to open</param>
        /// <returns>null on error, instance of PCI1710 on success</returns>
        public static PCI1710 OpenBoard(int index)
        {
            PCI1710 boardInstance;
            int nbBoard;
            IntPtr handle = IntPtr.Zero;

            // Get the number of boards
			nbBoard = GetBoardCount();
            if (nbBoard == -1)
            {
                Console.WriteLine("GetBoardCount failed!");
                return null;
            }

            // Check that the index is in the range
            if (index < 0 || index > nbBoard)
            {
                Console.WriteLine("Invalid index!");
                return null;
            }

            // Try to open the board
            if (DllImport.i_PCI1710_OpenBoardViaIndex((Byte)index, out handle) != 0)
            {
                Console.WriteLine("i_PCI1710_OpenBoardViaIndex failed!");
                return null;
            }

            // Create a new instance of the board
            boardInstance = new PCI1710();

            // Set its parameters
            boardInstance.index = index;
            boardInstance.handle = handle;

            // Return the instance
            return boardInstance;
        }

        /// <summary>
        /// Returns the number of PCI1710 boards plugged in the computer
        /// </summary>
        /// <returns>The number of boards</returns>
        public static int GetBoardCount()
        {
            int ret;
            byte nbBoard = 0;

            // Call the DLL function
            ret = DllImport.i_PCI1710_GetNumberOfBoards(out nbBoard);
            if (ret != 0)
				return -1;

             // Success
            return (int)nbBoard;
        }

        /// <summary>
        /// Returns the description of the last error that occurred
        /// </summary>
        /// <returns>A string describing the last error that occurred</returns>
        public string GetLastError()
        {
            // Call the DLL function
            return Marshal.PtrToStringAnsi(DllImport.pc_PCI1710_GetLastError(this.handle));
        }
#endregion
#region "Interrupt handling"
        /// <summary>
        /// Signals to all the listeners that an Interrupt event occurred.
        /// </summary>
        /// <param name="eventArgs">The arguments of the event</param>
        protected virtual void OnInterruptEventReceived(InterruptEventArgs eventArgs)
		{
            if (this.InterruptEventReceived != null)
                this.InterruptEventReceived(this, eventArgs);
        }

        /// <summary>
        /// Interrupt function - Called each time the board has generated an interrupt
        /// </summary>

        // /!\ /!\ /!\ This prototype is not standard, do not regenerate automatically!
        private void InterruptFunction(IntPtr handle, UInt32 status, UInt32 source, UInt32 mask, UInt32 argsSize, IntPtr args)
        {
            if (status != 0)
            {
                this.interruptEventArgs.fifoOverflow = true;
                this.OnInterruptEventReceived(this.interruptEventArgs);
            }
            else if ((source & 0xFFFFFFFF) != 0)
            {

				Byte [] data = new Byte[argsSize * sizeof(UInt32)];

				this.interruptEventArgs.interruptSource = source;
				this.interruptEventArgs.interruptMask = mask;

                // Convert the args
                this.interruptEventArgs.args = new UInt32[argsSize];
                Marshal.Copy(args, data, 0, (int)argsSize * sizeof(UInt32));
                for (int i = 0; i < argsSize; i++)
                    this.interruptEventArgs.args[i] = BitConverter.ToUInt32(data, i * sizeof(UInt32));

                // Signal the event
                this.OnInterruptEventReceived(this.interruptEventArgs);
            }

//##protect##"interruptFunctionBody"
//##protect##"interruptFunctionBody"
        }

        /// <summary>
        /// Set the board interrupt routine
        /// </summary>
        public int SetBoardIntRoutine()
        {
            return (int)DllImport.i_PCI1710_SetBoardIntRoutine(this.handle, interruptFunctionHandler);
        }

        /// <summary>
        /// Reset the board interrupt routine
        /// </summary>
        public int ResetBoardIntRoutine()
        {
            return (int)DllImport.i_PCI1710_ResetBoardIntRoutine(this.handle);
        }

#endregion
#region "PCI1710"

#endregion
#region "AdditionalFunctions"

		/// <summary>
		/// Configures the four module of the PCI1710 board.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="fileName0">Name of the configuration file for the function module 0</param>
		/// <param name="fileName1">Name of the configuration file for the function module 1</param>
		/// <param name="fileName2">Name of the configuration file for the function module 2</param>
		/// <param name="fileName3">Name of the configuration file for the function module 3</param>
		/// <param name="writeAddressError">If an error occurs, return the address of the read/write register</param>
        public int ConfigureAllModule(byte[] fileName0, byte[] fileName1, byte[] fileName2, byte[] fileName3, out UInt32 writeAddressError)
		{
			int returnValue;
//##protect##"functionStart_ConfigureAllModule"
//##protect##"functionStart_ConfigureAllModule"
            returnValue = DllImport.i_PCI1710_ConfigureAllModule(this.handle, fileName0, fileName1, fileName2, fileName3, out writeAddressError);
//##protect##"functionEnd_ConfigureAllModule"
//##protect##"functionEnd_ConfigureAllModule"
			return returnValue;
		}

		/// <summary>
		/// Returns the type of the hardware of the PCI1710 board.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="hardwareType">Type of the hardware (0: 10K10, 1: 10K20). The hardware type is necessary to be known for the user to configure the module. There are two subdirectories containing the config files. The path given to the function must be the good one, or the card could be destroyed</param>
		public int GetBoardHardwareType(out Byte hardwareType)
		{
			int returnValue;
//##protect##"functionStart_GetBoardHardwareType"
//##protect##"functionStart_GetBoardHardwareType"
			returnValue = DllImport.i_PCI1710_GetBoardHardwareType(this.handle, out hardwareType);
//##protect##"functionEnd_GetBoardHardwareType"
//##protect##"functionEnd_GetBoardHardwareType"
			return returnValue;
		}

        /// <summary>
        /// Returns the module configuration of the PCI1710 board.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="uc_ModuleNbr">Module number</param>
        /// <param name="pdw_ModuleConfiguration">Configuration name</param>
        public int GetModuleConfiguration(Byte uc_ModuleNbr, out UInt32 pdw_ModuleConfiguration)
        {
            int returnValue;
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            returnValue = DllImport.i_PCI1710_GetModuleConfiguration(this.handle, uc_ModuleNbr, out pdw_ModuleConfiguration);
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            return returnValue;
        }


        /// <summary>
        /// Writes to the EEPROM
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="dw_Offset">EEPROM offset</param>
        /// <param name="dw_EepromValue">Value to be written</param>
        public int EepromWrite(UInt32 dw_Offset, UInt32 dw_EepromValue)
        {
            int returnValue;
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            returnValue = DllImport.i_PCI1710_EepromAMCCWrite(this.handle, dw_Offset, dw_EepromValue);
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            return returnValue;
        }

        /// <summary>
        /// Reads from the EEPROM
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="dw_Offset">EEPROM offset</param>
        /// <param name="dw_EepromValue">Read EEPROM value</param>
        public int EepromRead(UInt32 dw_Offset, out UInt32 dw_Value)
        {
            int returnValue;
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            returnValue = DllImport.i_PCI1710_EepromAMCCRead(this.handle, dw_Offset, out dw_Value);
            //##protect##"functionStart_GetModuleConfiguration"
            //##protect##"functionStart_GetModuleConfiguration"
            return returnValue;
        }
  #endregion
#region "IncrementalCounter"

		/// <summary>
		/// Configures the counter operation mode of the selected module
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="counterRange">Selection of the counter range (0: 32-bit counter, 1: 163-bit counter)</param>
		/// <param name="firstCounterModus">Operation mode of the first counter (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode)</param>
		/// <param name="firstCounterOption">Option of the first counter (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or single, 0: hysteresis off, 96:hysteresis on)</param>
		/// <param name="secondCounterModus">Operation mode of the second counter (0: quadruple mode, 3: double mode, 15: simple mode, 128: direct mode)</param>
		/// <param name="secondCounterOption">Option of the second counter (if first counter mode is direct mode, 0: decrement, 96: increment; if first counter mode is quadruple, double or single, 0: hysteresis off, 96:hysteresis on)</param>
		public int InitCounter(Byte moduleNumber, Byte counterRange, Byte firstCounterModus, Byte firstCounterOption, Byte secondCounterModus, Byte secondCounterOption)
		{
			int returnValue;
//##protect##"functionStart_InitCounter"
//##protect##"functionStart_InitCounter"
			returnValue = DllImport.i_PCI1710_InitCounter(this.handle, moduleNumber, counterRange, firstCounterModus, firstCounterOption, secondCounterModus, secondCounterOption);
//##protect##"functionEnd_InitCounter"
//##protect##"functionEnd_InitCounter"
			return returnValue;
		}

		/// <summary>
		/// A test mode is predetermined for the test of the module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="testStatus">Auto test returned value (0: no error, 1: error on counter 1, 2: error on counter 2, 3: error on counter 3)</param>
		public int CounterAutoTest(out Byte testStatus)
		{
			int returnValue;
//##protect##"functionStart_CounterAutoTest"
//##protect##"functionStart_CounterAutoTest"
			returnValue = DllImport.i_PCI1710_CounterAutoTest(this.handle, out testStatus);
//##protect##"functionEnd_CounterAutoTest"
//##protect##"functionEnd_CounterAutoTest"
			return returnValue;
		}

		/// <summary>
		/// Deletes the counter value of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int ClearCounterValue(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_ClearCounterValue"
//##protect##"functionStart_ClearCounterValue"
			returnValue = DllImport.i_PCI1710_ClearCounterValue(this.handle, moduleNumber);
//##protect##"functionEnd_ClearCounterValue"
//##protect##"functionEnd_ClearCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Deletes all the counter values.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		public int ClearAllCounterValue()
		{
			int returnValue;
//##protect##"functionStart_ClearAllCounterValue"
//##protect##"functionStart_ClearAllCounterValue"
			returnValue = DllImport.i_PCI1710_ClearAllCounterValue(this.handle);
//##protect##"functionEnd_ClearAllCounterValue"
//##protect##"functionEnd_ClearAllCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Disables or enables the software filter in the selected module for the inputs A, B, C and D.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PCIInputClock">Selection of the bus clock (30: 30 MHz, 33: 33 MHz, 40: 40 MHz)</param>
		/// <param name="filter">Selection of the filter for the inputs A, B, C and D (0: filter not used, 1: 100 ns, 2: 150 ns, 3: 200 ns, 4: 250 ns, 5: 300 ns, 6: 350 ns, 7: 400 ns, 8: 450 ns, 9: 500 ns, 10: 550 ns, 11: 600 ns, 12: 650 ns, 13: 700 ns, 14: 750 ns, 15: 800 ns)</param>
		public int SetInputFilter(Byte moduleNumber, Byte PCIInputClock, Byte filter)
		{
			int returnValue;
//##protect##"functionStart_SetInputFilter"
//##protect##"functionStart_SetInputFilter"
			returnValue = DllImport.i_PCI1710_SetInputFilter(this.handle, moduleNumber, PCIInputClock, filter);
//##protect##"functionEnd_SetInputFilter"
//##protect##"functionEnd_SetInputFilter"
			return returnValue;
		}

        /// <summary>
        /// Disables or enables the software filter in the selected module for the inputs E, F, G.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="filter">Selection of the filter for the inputs E, F, G (0: filter not used, 1: 100 ns, 2: 150 ns, 3: 200 ns, 4: 250 ns, 5: 300 ns, 6: 350 ns, 7: 400 ns, 8: 450 ns, 9: 500 ns, 10: 550 ns, 11: 600 ns, 12: 650 ns, 13: 700 ns, 14: 750 ns, 15: 800 ns)</param>
        public int SetInputFilterEFG(Byte moduleNumber, Byte filter)
        {
            int returnValue;
//##protect##"functionStart_SetInputFilter"
//##protect##"functionStart_SetInputFilter"
            returnValue = DllImport.i_PCI1710_SetInputFilterEFG(this.handle, moduleNumber, filter);
//##protect##"functionEnd_SetInputFilter"
//##protect##"functionEnd_SetInputFilter"
            return returnValue;
        }

        /// <summary>
        /// Configures the H output behavior. A pulse of 400ns can be generated by the compare event.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="sourceSelect">	Source selection (0: manually set using SetDigitalChlOn/Off, 1: pulses are generated by compare events)</param>
        public int ConfigDigitalChlUse(Byte moduleNumber, Byte sourceSelect)
        {
            int returnValue;
//##protect##"functionStart_SetInputFilter"
//##protect##"functionStart_SetInputFilter"
            returnValue = DllImport.i_PCI1710_ConfigDigitalChlUse(this.handle, moduleNumber, sourceSelect);
//##protect##"functionEnd_SetInputFilter"
//##protect##"functionEnd_SetInputFilter"
            return returnValue;
        }


        /// <summary>
        /// 
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="sourceSelect">	Source selection (0: manually set using SetDigitalChlOn/Off, 1: pulses are generated by compare events)</param>
        public int InitModuloCompareLogic(Byte moduleNumber, UInt32 compareValue, Byte compareHysteresis)
        {
            int returnValue;
//##protect##"functionStart_SetInputFilter"
//##protect##"functionStart_SetInputFilter"
            returnValue = DllImport.i_PCI1710_InitModuloCompareLogic(this.handle, moduleNumber, compareValue, compareHysteresis);
//##protect##"functionEnd_SetInputFilter"
//##protect##"functionEnd_SetInputFilter"
            return returnValue;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="sourceSelect">	Source selection (0: manually set using SetDigitalChlOn/Off, 1: pulses are generated by compare events)</param>
        public int ReadCompareLatchRegister(Byte moduleNumber, out UInt32 latchValue)
        {
            int returnValue;
//##protect##"functionStart_SetInputFilter"
//##protect##"functionStart_SetInputFilter"
            returnValue = DllImport.i_PCI1710_ReadCompareLatchRegister(this.handle, moduleNumber, out latchValue);
//##protect##"functionEnd_SetInputFilter"
//##protect##"functionEnd_SetInputFilter"
            return returnValue;
        }


		/// <summary>
		/// Latching of the current value of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="latchReg">Selection of the latch register (0: for the first latch register, 1: for the second latch register)</param>
		public int LatchCounter(Byte moduleNumber, Byte latchReg)
		{
			int returnValue;
//##protect##"functionStart_LatchCounter"
//##protect##"functionStart_LatchCounter"
			returnValue = DllImport.i_PCI1710_LatchCounter(this.handle, moduleNumber, latchReg);
//##protect##"functionEnd_LatchCounter"
//##protect##"functionEnd_LatchCounter"
			return returnValue;
		}

		/// <summary>
		/// Reads the status of the selected latch register of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="latchReg">Selection of the latch register (0: for the first latch register, 1: for the second latch register)</param>
		/// <param name="latchStatus">Latch register status (0: no latch, 1: a software latch was generated, 2: a hardware latch was generated, 3: a software latch and a hardware latch were generated)</param>
		public int ReadLatchRegisterStatus(Byte moduleNumber, Byte latchReg, out Byte latchStatus)
		{
			int returnValue;
//##protect##"functionStart_ReadLatchRegisterStatus"
//##protect##"functionStart_ReadLatchRegisterStatus"
			returnValue = DllImport.i_PCI1710_ReadLatchRegisterStatus(this.handle, moduleNumber, latchReg, out latchStatus);
//##protect##"functionEnd_ReadLatchRegisterStatus"
//##protect##"functionEnd_ReadLatchRegisterStatus"
			return returnValue;
		}

		/// <summary>
		/// Reads the value of the selected latch register of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="latchReg">Selection of the latch register (0: for the first latch register, 1: for the second latch register)</param>
		/// <param name="latchValue">Latch register value</param>
		public int ReadLatchRegisterValue(Byte moduleNumber, Byte latchReg, out UInt32 latchValue)
		{
			int returnValue;
//##protect##"functionStart_ReadLatchRegisterValue"
//##protect##"functionStart_ReadLatchRegisterValue"
			returnValue = DllImport.i_PCI1710_ReadLatchRegisterValue(this.handle, moduleNumber, latchReg, out latchValue);
//##protect##"functionEnd_ReadLatchRegisterValue"
//##protect##"functionEnd_ReadLatchRegisterValue"
			return returnValue;
		}

		/// <summary>
		/// Enables the latch interrupt of the selected module. Each hardware latched generates an interrupt.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int EnableLatchInterrupt(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_EnableLatchInterrupt"
//##protect##"functionStart_EnableLatchInterrupt"
			returnValue = DllImport.i_PCI1710_EnableLatchInterrupt(this.handle, moduleNumber);
//##protect##"functionEnd_EnableLatchInterrupt"
//##protect##"functionEnd_EnableLatchInterrupt"
			return returnValue;
		}

		/// <summary>
		/// Disables the latch interrupt of the selected module. Each hardware latched generates an interrupt.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int DisableLatchInterrupt(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_DisableLatchInterrupt"
//##protect##"functionStart_DisableLatchInterrupt"
			returnValue = DllImport.i_PCI1710_DisableLatchInterrupt(this.handle, moduleNumber);
//##protect##"functionEnd_DisableLatchInterrupt"
//##protect##"functionEnd_DisableLatchInterrupt"
			return returnValue;
		}

		/// <summary>
		/// Latches a 16-bit counter from the selected module in the first register and returns the latched value.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="selectedCounter">Selection of the 16-bit counter (0 or 1)</param>
		/// <param name="counterValue">16-bit counter value</param>
		public int Read16BitCounterValue(Byte moduleNumber, Byte selectedCounter, out UInt32 counterValue)
		{
			int returnValue;
//##protect##"functionStart_Read16BitCounterValue"
//##protect##"functionStart_Read16BitCounterValue"
			returnValue = DllImport.i_PCI1710_Read16BitCounterValue(this.handle, moduleNumber, selectedCounter, out counterValue);
//##protect##"functionEnd_Read16BitCounterValue"
//##protect##"functionEnd_Read16BitCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Latches the 32-bit counter from the selected module in the first register and returns the latched value.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="counterValue">32-bit counter value</param>
		public int Read32BitCounterValue(Byte moduleNumber, out UInt32 counterValue)
		{
			int returnValue;
//##protect##"functionStart_Read32BitCounterValue"
//##protect##"functionStart_Read32BitCounterValue"
			returnValue = DllImport.i_PCI1710_Read32BitCounterValue(this.handle, moduleNumber, out counterValue);
//##protect##"functionEnd_Read32BitCounterValue"
//##protect##"functionEnd_Read32BitCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Writes the 16-bit value into a 16-bit counter of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="selectedCounter">Selection of the 16-bit counter (0 or 1)</param>
		/// <param name="writeValue">16-bit write value</param>
		public int Write16BitCounterValue(Byte moduleNumber, Byte selectedCounter, UInt32 writeValue)
		{
			int returnValue;
//##protect##"functionStart_Write16BitCounterValue"
//##protect##"functionStart_Write16BitCounterValue"
			returnValue = DllImport.i_PCI1710_Write16BitCounterValue(this.handle, moduleNumber, selectedCounter, writeValue);
//##protect##"functionEnd_Write16BitCounterValue"
//##protect##"functionEnd_Write16BitCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Writes the 32-bit value into the counter of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="writeValue">32-bit write value</param>
		public int Write32BitCounterValue(Byte moduleNumber, UInt32 writeValue)
		{
			int returnValue;
//##protect##"functionStart_Write32BitCounterValue"
//##protect##"functionStart_Write32BitCounterValue"
			returnValue = DllImport.i_PCI1710_Write32BitCounterValue(this.handle, moduleNumber, writeValue);
//##protect##"functionEnd_Write32BitCounterValue"
//##protect##"functionEnd_Write32BitCounterValue"
			return returnValue;
		}

		/// <summary>
		/// Initializes the index that corresponds with the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="referenceAction">Determines if the reference for the index-transfer shall be reset or not (0: reference has not an importance, 1: reference shall be set for the index transfer)</param>
		/// <param name="indexOperation">Index operation mode (0: after an index signal (high level) the counter value (32-bit) is latched into the first latch register, 1: after an index signal (low level), the counter value (32-bit) is latched into the first latch register, 2: after an index signal (high level), the counter value is deleted (32-bit), 3: after an index signal (low level), the counter value is deleted (32-bit), 4: after an index signal (high level), the counter value (32-bit) is latched into the first latch register and then deleted (32-bit), 5: after an index signal (low level), the counter value (32-bit) is latched into the first latch register and then deleted (32-bit))</param>
		/// <param name="autoMode">Enables or disables the automatic index reset (0: disables, 1: enables)</param>
		/// <param name="interruptEnable">Enables or disables the interrupt (0: disables, 1: enables)</param>
		public int InitIndex(Byte moduleNumber, Byte referenceAction, Byte indexOperation, Byte autoMode, Byte interruptEnable)
		{
			int returnValue;
//##protect##"functionStart_InitIndex"
//##protect##"functionStart_InitIndex"
			returnValue = DllImport.i_PCI1710_InitIndex(this.handle, moduleNumber, referenceAction, indexOperation, autoMode, interruptEnable);
//##protect##"functionEnd_InitIndex"
//##protect##"functionEnd_InitIndex"
			return returnValue;
		}

		/// <summary>
		/// Enables the index actions.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int EnableIndex(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_EnableIndex"
//##protect##"functionStart_EnableIndex"
			returnValue = DllImport.i_PCI1710_EnableIndex(this.handle, moduleNumber);
//##protect##"functionEnd_EnableIndex"
//##protect##"functionEnd_EnableIndex"
			return returnValue;
		}

		/// <summary>
		/// Disables the index actions.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int DisableIndex(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_DisableIndex"
//##protect##"functionStart_DisableIndex"
			returnValue = DllImport.i_PCI1710_DisableIndex(this.handle, moduleNumber);
//##protect##"functionEnd_DisableIndex"
//##protect##"functionEnd_DisableIndex"
			return returnValue;
		}

		/// <summary>
		/// Returns the index status.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="indexStatus">Index status (0: no index, 1: an index is determined)</param>
		public int GetIndexStatus(Byte moduleNumber, out Byte indexStatus)
		{
			int returnValue;
//##protect##"functionStart_GetIndexStatus"
//##protect##"functionStart_GetIndexStatus"
			returnValue = DllImport.i_PCI1710_GetIndexStatus(this.handle, moduleNumber, out indexStatus);
//##protect##"functionEnd_GetIndexStatus"
//##protect##"functionEnd_GetIndexStatus"
			return returnValue;
		}

		/// <summary>
		/// Determines the hardware source for the index and the reference logic.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="sourceSelection">Source of the index and the reference logic (0: source 0 (index logic connected to the differential input C and reference logic to the 24 V input E), 1: source 1 (reference logic connected to the differential input C and index logic to the 24 V input E))</param>
		public int SetIndexAndReferenceSource(Byte moduleNumber, Byte sourceSelection)
		{
			int returnValue;
//##protect##"functionStart_SetIndexAndReferenceSource"
//##protect##"functionStart_SetIndexAndReferenceSource"
			returnValue = DllImport.i_PCI1710_SetIndexAndReferenceSource(this.handle, moduleNumber, sourceSelection);
//##protect##"functionEnd_SetIndexAndReferenceSource"
//##protect##"functionEnd_SetIndexAndReferenceSource"
			return returnValue;
		}

		/// <summary>
		/// Initializes the reference that corresponds with the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="referenceLevel">Reference level (0: if '0', reference initialized, 1: if '1', reference initialized)</param>
		public int InitReference(Byte moduleNumber, Byte referenceLevel)
		{
			int returnValue;
//##protect##"functionStart_InitReference"
//##protect##"functionStart_InitReference"
			returnValue = DllImport.i_PCI1710_InitReference(this.handle, moduleNumber, referenceLevel);
//##protect##"functionEnd_InitReference"
//##protect##"functionEnd_InitReference"
			return returnValue;
		}

		/// <summary>
		/// Returns the reference status.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="referenceStatus">Reference status (0: no reference, 1: a reference was enabled)</param>
		public int GetReferenceStatus(Byte moduleNumber, out Byte referenceStatus)
		{
			int returnValue;
//##protect##"functionStart_GetReferenceStatus"
//##protect##"functionStart_GetReferenceStatus"
			returnValue = DllImport.i_PCI1710_GetReferenceStatus(this.handle, moduleNumber, out referenceStatus);
//##protect##"functionEnd_GetReferenceStatus"
//##protect##"functionEnd_GetReferenceStatus"
			return returnValue;
		}

		/// <summary>
		/// Returns the UAS status.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="UASStatus">UAS status (0: UAS is set on low, 1: UAS is set on high)</param>
		public int GetUASStatus(Byte moduleNumber, out Byte UASStatus)
		{
			int returnValue;
//##protect##"functionStart_GetUASStatus"
//##protect##"functionStart_GetUASStatus"
			returnValue = DllImport.i_PCI1710_GetUASStatus(this.handle, moduleNumber, out UASStatus);
//##protect##"functionEnd_GetUASStatus"
//##protect##"functionEnd_GetUASStatus"
			return returnValue;
		}

		/// <summary>
		/// Returns the CB status.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="CBStatus">CB status (0: no counter overflow, 1: counter overflow)</param>
		public int GetCBStatus(Byte moduleNumber, out Byte CBStatus)
		{
			int returnValue;
//##protect##"functionStart_GetCBStatus"
//##protect##"functionStart_GetCBStatus"
			returnValue = DllImport.i_PCI1710_GetCBStatus(this.handle, moduleNumber, out CBStatus);
//##protect##"functionEnd_GetCBStatus"
//##protect##"functionEnd_GetCBStatus"
			return returnValue;
		}

		/// <summary>
		/// Returns the CB status of the two 16-bit counters.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="CBStatusCounter0">CB status of the 16-bit counter 0</param>
		/// <param name="CBStatusCounter1">CB status of the 16-bit counter 1</param>
		public int Get16BitCBStatus(Byte moduleNumber, out Byte CBStatusCounter0, out Byte CBStatusCounter1)
		{
			int returnValue;
//##protect##"functionStart_Get16BitCBStatus"
//##protect##"functionStart_Get16BitCBStatus"
			returnValue = DllImport.i_PCI1710_Get16BitCBStatus(this.handle, moduleNumber, out CBStatusCounter0, out CBStatusCounter1);
//##protect##"functionEnd_Get16BitCBStatus"
//##protect##"functionEnd_Get16BitCBStatus"
			return returnValue;
		}

		/// <summary>
		/// Gets the UD status of the counter runout.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="UDStatus">UD status (0: counter runout in the selected mode, 1: counter runout in the selected mode upwards</param>
		public int GetUDStatus(Byte moduleNumber, out Byte UDStatus)
		{
			int returnValue;
//##protect##"functionStart_GetUDStatus"
//##protect##"functionStart_GetUDStatus"
			returnValue = DllImport.i_PCI1710_GetUDStatus(this.handle, moduleNumber, out UDStatus);
//##protect##"functionEnd_GetUDStatus"
//##protect##"functionEnd_GetUDStatus"
			return returnValue;
		}

		/// <summary>
		/// Returns the latched status of the counter runout, after an interrupt is generated.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="UDStatus">UD status (0: counter runout in the selected mode downwards, 1: counter runout in the selected mode upwards, 2: there is no index interrupt)</param>
		public int GetInterruptUDLatchedStatus(Byte moduleNumber, out Byte UDStatus)
		{
			int returnValue;
//##protect##"functionStart_GetInterruptUDLatchedStatus"
//##protect##"functionStart_GetInterruptUDLatchedStatus"
			returnValue = DllImport.i_PCI1710_GetInterruptUDLatchedStatus(this.handle, moduleNumber, out UDStatus);
//##protect##"functionEnd_GetInterruptUDLatchedStatus"
//##protect##"functionEnd_GetInterruptUDLatchedStatus"
			return returnValue;
		}

		/// <summary>
		/// Initializes the external pulse level for the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="externalStrobe">Selection of the external pulse (strobe) (0: external pulse A, 1: external pulse B)</param>
		/// <param name="externalStrobeLevel">Level of the external pulse (0: external latch is generated at '0', 1: external latch is generated at '1' (standard configuration))</param>
		public int InitExternalStrobe(Byte moduleNumber, Byte externalStrobe, Byte externalStrobeLevel)
		{
			int returnValue;
//##protect##"functionStart_InitExternalStrobe"
//##protect##"functionStart_InitExternalStrobe"
			returnValue = DllImport.i_PCI1710_InitExternalStrobe(this.handle, moduleNumber, externalStrobe, externalStrobeLevel);
//##protect##"functionEnd_InitExternalStrobe"
//##protect##"functionEnd_InitExternalStrobe"
			return returnValue;
		}

		/// <summary>
		/// Sets the 32-bit compare value. An interrupt is generated as soon as the counter has reached the compare value.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="compareValue">32-bit compare value</param>
		public int InitCompareLogic(Byte moduleNumber, UInt32 compareValue)
		{
			int returnValue;
//##protect##"functionStart_InitCompareLogic"
//##protect##"functionStart_InitCompareLogic"
			returnValue = DllImport.i_PCI1710_InitCompareLogic(this.handle, moduleNumber, compareValue);
//##protect##"functionEnd_InitCompareLogic"
//##protect##"functionEnd_InitCompareLogic"
			return returnValue;
		}

		/// <summary>
		/// Enables the 32-bit compare logic. An interrupt is generated as soon as the counter has reached the compare value.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int EnableCompareLogic(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_EnableCompareLogic"
//##protect##"functionStart_EnableCompareLogic"
			returnValue = DllImport.i_PCI1710_EnableCompareLogic(this.handle, moduleNumber);
//##protect##"functionEnd_EnableCompareLogic"
//##protect##"functionEnd_EnableCompareLogic"
			return returnValue;
		}

		/// <summary>
		/// Disables the 32-bit compare logic.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int DisableCompareLogic(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_DisableCompareLogic"
//##protect##"functionStart_DisableCompareLogic"
			returnValue = DllImport.i_PCI1710_DisableCompareLogic(this.handle, moduleNumber);
//##protect##"functionEnd_DisableCompareLogic"
//##protect##"functionEnd_DisableCompareLogic"
			return returnValue;
		}

		/// <summary>
		/// Sets the digital output of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int SetDigitalChlOn(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_SetDigitalChlOn"
//##protect##"functionStart_SetDigitalChlOn"
			returnValue = DllImport.i_PCI1710_SetDigitalChlOn(this.handle, moduleNumber);
//##protect##"functionEnd_SetDigitalChlOn"
//##protect##"functionEnd_SetDigitalChlOn"
			return returnValue;
		}

		/// <summary>
		/// Resets the digital output of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int SetDigitalChlOff(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_SetDigitalChlOff"
//##protect##"functionStart_SetDigitalChlOff"
			returnValue = DllImport.i_PCI1710_SetDigitalChlOff(this.handle, moduleNumber);
//##protect##"functionEnd_SetDigitalChlOff"
//##protect##"functionEnd_SetDigitalChlOff"
			return returnValue;
		}

#endregion
#region "PulseEncoder"
        /// <summary>
        /// Configure the pulse encoder .
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="pulseEncoderNumber">Pulse encoder selection (0 to 3)</param>
        /// <param name="inputLevelSelection">b_InputLevelSelection Input level selection (0 or 1)</param>
        /// <param name="triggerOutputAction">Digital trigger output action</param>
        /// <param name="dw_StartValue">Pulse encoder start value (1 to 4294967295).</param>
        public int InitPulseEncoder(Byte moduleNumber, Byte pulseEncoderNumber, Byte inputLevelSelection, Byte triggerOutputAction, UInt32 dw_StartValue)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_InitPulseEncoder(this.handle, moduleNumber, pulseEncoderNumber, inputLevelSelection, triggerOutputAction, dw_StartValue);
            return returnValue;
        }
        /// <summary>
        /// Enable the selected pulse encoder.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="pulseEncoderNumber">Pulse encoder selection (0 to 3)</param>
        /// <param name="cycleSelection">b_CycleSelection (APCI1710_CONTINUOUS or APCI1710_SINGLE)</param>
        /// <param name="interruptHandling">b_InterruptHandling Interrupt can be generated when the pulse encoder has run down.</param>
        public int EnablePulseEncoder(Byte moduleNumber, Byte pulseEncoderNumber, Byte cycleSelection, Byte interruptHandling)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_EnablePulseEncoder(this.handle, moduleNumber, pulseEncoderNumber, cycleSelection, interruptHandling);
            return returnValue;
        }
        /// <summary>
        /// Disable the selected pulse encoder.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="pulseEncoderNumber">Pulse encoder selection (0 to 3)</param>
        public int DisablePulseEncoder(Byte moduleNumber, Byte pulseEncoderNumber)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_DisablePulseEncoder(this.handle, moduleNumber, pulseEncoderNumber);
            return returnValue;
        }
        /// <summary>
        /// Reads the pulse encoder status.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="status">Pulse encoder status (0 : overflow occurs, 1 . Overflow occurs)</param>
        public int ReadPulseEncoderStatus(Byte moduleNumber, Byte pulseEncoderNumber, out Byte status)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_ReadPulseEncoderStatus(this.handle, moduleNumber, pulseEncoderNumber, out status);
            return returnValue;
        }
        /// <summary>
        /// Reads the pulse encoder value.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="readValue">Pulse encoder selection (0 to 3)</param>
        public int ReadPulseEncoderValue(Byte moduleNumber, Byte pulseEncoderNumber, out UInt32 readValue)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_ReadPulseEncoderValue(this.handle, moduleNumber, pulseEncoderNumber, out readValue);
            return returnValue;
        }
        /// <summary>
        /// Writes a 32 bits value.
        /// </summary>
        /// <param name="deviceHandle">Handle of the board</param>
        /// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
        /// <param name="pulseEncoderNumber">Pulse encoder selection (0 to 3)</param>
        /// <param name="writeValue">32-bit value to be written</param>
        public int WritePulseEncoderValue(Byte moduleNumber, Byte pulseEncoderNumber, UInt32 writeValue)
        {
            int returnValue;
            returnValue = DllImport.i_PCI1710_WritePulseEncoderValue(this.handle, moduleNumber, pulseEncoderNumber, writeValue);
            return returnValue;
        }
#endregion
#region "Timer82C54"

        /// <summary>
		/// Initializes a 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="timerMode">Mode in which the timer has to be initialized (from 0 to 5)</param>
		/// <param name="reloadValue">Reload value of the timer (from 0 to 4 294 967 295)</param>
		/// <param name="inputClockSelection">Selection of the clock to use (1: external clock, 2: internal 10 MHz clock). For the timer 0, only the internal 10 MHz clock is available</param>
		/// <param name="inputClockLevel">Level of the clock (0: active at low, 1: active a high (input inverted))</param>
		/// <param name="outputLevel">Selection of the output clock level (0: active at low (inverted), 1: active a high)</param>
		/// <param name="hardwareGateLevel">Selection of the hardware gate level (0: active at low (inverted), 1: active a high). If the external gate is not used, this parameter must be set to 0</param>
		public int InitTimer(Byte moduleNumber, Byte timerNumber, Byte timerMode, UInt32 reloadValue, Byte inputClockSelection, Byte inputClockLevel, Byte outputLevel, Byte hardwareGateLevel)
		{
			int returnValue;
//##protect##"functionStart_InitTimer"
//##protect##"functionStart_InitTimer"
			returnValue = DllImport.i_PCI1710_InitTimer(this.handle, moduleNumber, timerNumber, timerMode, reloadValue, inputClockSelection, inputClockLevel, outputLevel, hardwareGateLevel);
//##protect##"functionEnd_InitTimer"
//##protect##"functionEnd_InitTimer"
			return returnValue;
		}

		/// <summary>
		/// Enables and starts a 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="interruptEnable">Enable interrupt flag (0: interrupt disabled, 1: interrupt enabled)</param>
		public int EnableTimer(Byte moduleNumber, Byte timerNumber, Byte interruptEnable)
		{
			int returnValue;
//##protect##"functionStart_EnableTimer"
//##protect##"functionStart_EnableTimer"
			returnValue = DllImport.i_PCI1710_EnableTimer(this.handle, moduleNumber, timerNumber, interruptEnable);
//##protect##"functionEnd_EnableTimer"
//##protect##"functionEnd_EnableTimer"
			return returnValue;
		}

		/// <summary>
		/// Stops and releases a 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		public int DisableTimer(Byte moduleNumber, Byte timerNumber)
		{
			int returnValue;
//##protect##"functionStart_DisableTimer"
//##protect##"functionStart_DisableTimer"
			returnValue = DllImport.i_PCI1710_DisableTimer(this.handle, moduleNumber, timerNumber);
//##protect##"functionEnd_DisableTimer"
//##protect##"functionEnd_DisableTimer"
			return returnValue;
		}

		/// <summary>
		/// Reads the current value of a 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="timerValue">Value of the timer</param>
		public int ReadTimerValue(Byte moduleNumber, Byte timerNumber, out UInt32 timerValue)
		{
			int returnValue;
//##protect##"functionStart_ReadTimerValue"
//##protect##"functionStart_ReadTimerValue"
			returnValue = DllImport.i_PCI1710_ReadTimerValue(this.handle, moduleNumber, timerNumber, out timerValue);
//##protect##"functionEnd_ReadTimerValue"
//##protect##"functionEnd_ReadTimerValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the values of the three 82c54 timers.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerValue">Array containing the the current values of the three timers. The array must be allocated before calling this function</param>
		public int ReadAllTimerValue(Byte moduleNumber, UInt32 [] timerValue)
		{
			int returnValue;
//##protect##"functionStart_ReadAllTimerValue"
//##protect##"functionStart_ReadAllTimerValue"
			returnValue = DllImport.i_PCI1710_ReadAllTimerValue(this.handle, moduleNumber, timerValue);
//##protect##"functionEnd_ReadAllTimerValue"
//##protect##"functionEnd_ReadAllTimerValue"
			return returnValue;
		}

		/// <summary>
		/// Returns the output level of a 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="outputLevel">Level of the output (0: low, 1: high)</param>
		public int GetTimerOutputLevel(Byte moduleNumber, Byte timerNumber, out Byte outputLevel)
		{
			int returnValue;
//##protect##"functionStart_GetTimerOutputLevel"
//##protect##"functionStart_GetTimerOutputLevel"
			returnValue = DllImport.i_PCI1710_GetTimerOutputLevel(this.handle, moduleNumber, timerNumber, out outputLevel);
//##protect##"functionEnd_GetTimerOutputLevel"
//##protect##"functionEnd_GetTimerOutputLevel"
			return returnValue;
		}

		/// <summary>
		/// Return the status of the timer value for a given 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="timerStatus">Status of the timer (1 -> timer value is 0, 0 -> timer value differs from 0 (i.e. timer runs or is initialized))</param>
		public int GetTimerProgressStatus(Byte moduleNumber, Byte timerNumber, out Byte timerStatus)
		{
			int returnValue;
//##protect##"functionStart_GetTimerProgressStatus"
//##protect##"functionStart_GetTimerProgressStatus"
			returnValue = DllImport.i_PCI1710_GetTimerProgressStatus(this.handle, moduleNumber, timerNumber, out timerStatus);
//##protect##"functionEnd_GetTimerProgressStatus"
//##protect##"functionEnd_GetTimerProgressStatus"
			return returnValue;
		}

        /// <summary>
		/// Return the status of a given 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="timerStatus">Status of the timer (0: stopped, 1: running)</param>
		public int GetTimerProgressStatusEx(Byte moduleNumber, Byte timerNumber, out Byte timerStatus)
		{
			int returnValue;
//##protect##"functionStart_GetTimerProgressStatusEx"
//##protect##"functionStart_GetTimerProgressStatusEx"
			returnValue = DllImport.i_PCI1710_GetTimerProgressStatusEx(this.handle, moduleNumber, timerNumber, out timerStatus);
//##protect##"functionEnd_GetTimerProgressStatusEx"
//##protect##"functionEnd_GetTimerProgressStatusEx"
			return returnValue;
		}
        
		/// <summary>
		/// Writes the value of a given 82c54 timer.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="timerNumber">Number of the timer (from 0 to 2)</param>
		/// <param name="value">Value to write</param>
		public int WriteTimerValue(Byte moduleNumber, Byte timerNumber, UInt32 value)
		{
			int returnValue;
//##protect##"functionStart_WriteTimerValue"
//##protect##"functionStart_WriteTimerValue"
			returnValue = DllImport.i_PCI1710_WriteTimerValue(this.handle, moduleNumber, timerNumber, value);
//##protect##"functionEnd_WriteTimerValue"
//##protect##"functionEnd_WriteTimerValue"
			return returnValue;
		}

#endregion
#region "DigitalIO"

		/// <summary>
		/// Reads the value of the digital inputs.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="digitalInputs">Values of the digital inputs (from 0x0 to 0x7, bit 0: input C, bit 1: input D, bit 2: input E, bit 3: input F, bit 4: input G, bit 5: input A, bit 6: input B)</param>
		public int ReadDigitalInputs(Byte moduleNumber, out Byte digitalInputs)
		{
			int returnValue;
//##protect##"functionStart_ReadDigitalInputs"
//##protect##"functionStart_ReadDigitalInputs"
			returnValue = DllImport.i_PCI1710_ReadDigitalInputs(this.handle, moduleNumber, out digitalInputs);
//##protect##"functionEnd_ReadDigitalInputs"
//##protect##"functionEnd_ReadDigitalInputs"
			return returnValue;
		}

		/// <summary>
		/// Sets on the selected digital outputs.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="digitalOutputs">Outputs to set on (from 0x0 to 0x7, bit 0: output H, bit 1: output A, bit 2: output B)</param>
		public int SetDigitalOutputsOn(Byte moduleNumber, Byte digitalOutputs)
		{
			int returnValue;
//##protect##"functionStart_SetDigitalOutputsOn"
//##protect##"functionStart_SetDigitalOutputsOn"
			returnValue = DllImport.i_PCI1710_SetDigitalOutputsOn(this.handle, moduleNumber, digitalOutputs);
//##protect##"functionEnd_SetDigitalOutputsOn"
//##protect##"functionEnd_SetDigitalOutputsOn"
			return returnValue;
		}

		/// <summary>
		/// Sets off the selected digital outputs.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="digitalOutputs">Outputs to set on (from 0x0 to 0x7, bit 0: output H, bit 1: output A, bit 2: output B)</param>
		public int SetDigitalOutputsOff(Byte moduleNumber, Byte digitalOutputs)
		{
			int returnValue;
//##protect##"functionStart_SetDigitalOutputsOff"
//##protect##"functionStart_SetDigitalOutputsOff"
			returnValue = DllImport.i_PCI1710_SetDigitalOutputsOff(this.handle, moduleNumber, digitalOutputs);
//##protect##"functionEnd_SetDigitalOutputsOff"
//##protect##"functionEnd_SetDigitalOutputsOff"
			return returnValue;
		}

		/// <summary>
		/// Sets the mode of the digital inputs/outputs A and B.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portAMode">Configuration channel A (0: input, 1: output)</param>
		/// <param name="portBMode">Configuration channel B (0: input, 1: output)</param>
		public int SetPortConfiguration(Byte moduleNumber, Byte portAMode, Byte portBMode)
		{
			int returnValue;
//##protect##"functionStart_SetPortConfiguration"
//##protect##"functionStart_SetPortConfiguration"
			returnValue = DllImport.i_PCI1710_SetPortConfiguration(this.handle, moduleNumber, portAMode, portBMode);
//##protect##"functionEnd_SetPortConfiguration"
//##protect##"functionEnd_SetPortConfiguration"
			return returnValue;
		}

		/// <summary>
		/// Sets the digital output memory on or off.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="memoryFlag">Digital output memory flag (0: off, 1: on)</param>
		public int SetDigitalOutputMemory(Byte memoryFlag)
		{
			int returnValue;
//##protect##"functionStart_SetDigitalOutputMemory"
//##protect##"functionStart_SetDigitalOutputMemory"
			returnValue = DllImport.i_PCI1710_SetDigitalOutputMemory(this.handle, memoryFlag);
//##protect##"functionEnd_SetDigitalOutputMemory"
//##protect##"functionEnd_SetDigitalOutputMemory"
			return returnValue;
		}

#endregion
#region "TTL"

		/// <summary>
		/// Permits the configure on a given module the TTL I/O in input or output mode.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portAMode">Mode of the port A (0: input, 1: output)</param>
		/// <param name="portBMode">Mode of the port B (0: input, 1: output)</param>
		/// <param name="portCMode">Mode of the port C (0: input, 1: output)</param>
		/// <param name="portDMode">Mode of the port D (0: input, 1: output)</param>
		public int InitTTLIODirection(Byte moduleNumber, Byte portAMode, Byte portBMode, Byte portCMode, Byte portDMode)
		{
			int returnValue;
//##protect##"functionStart_InitTTLIODirection"
//##protect##"functionStart_InitTTLIODirection"
			returnValue = DllImport.i_PCI1710_InitTTLIODirection(this.handle, moduleNumber, portAMode, portBMode, portCMode, portDMode);
//##protect##"functionEnd_InitTTLIODirection"
//##protect##"functionEnd_InitTTLIODirection"
			return returnValue;
		}

		/// <summary>
		/// Reads the value of a given TTL digital input on a given port and module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portNbr">Number of the port in which the input is located (0: port A, 1: port B, 2: port c, 3: port D)</param>
		/// <param name="channelNbr">Channel to read (from 0 to 7)</param>
		/// <param name="value">Value of the channel</param>
		public int ReadTTLIOChannelValue(Byte moduleNumber, Byte portNbr, Byte channelNbr, out Byte value)
		{
			int returnValue;
//##protect##"functionStart_ReadTTLIOChannelValue"
//##protect##"functionStart_ReadTTLIOChannelValue"
			returnValue = DllImport.i_PCI1710_ReadTTLIOChannelValue(this.handle, moduleNumber, portNbr, channelNbr, out value);
//##protect##"functionEnd_ReadTTLIOChannelValue"
//##protect##"functionEnd_ReadTTLIOChannelValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the value of the TTL digital inputs of a given port and module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portNbr">Number of the port in which the input is located (0: port A, 1: port B, 2: port c, 3: port D)</param>
		/// <param name="value">Status of the port</param>
		public int ReadTTLIOPortValue(Byte moduleNumber, Byte portNbr, out Byte value)
		{
			int returnValue;
//##protect##"functionStart_ReadTTLIOPortValue"
//##protect##"functionStart_ReadTTLIOPortValue"
			returnValue = DllImport.i_PCI1710_ReadTTLIOPortValue(this.handle, moduleNumber, portNbr, out value);
//##protect##"functionEnd_ReadTTLIOPortValue"
//##protect##"functionEnd_ReadTTLIOPortValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the value of the TTL digital inputs of all the ports of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="value">Status of all the ports</param>
		public int ReadTTLIOAllPortValue(Byte moduleNumber, out UInt32 value)
		{
			int returnValue;
//##protect##"functionStart_ReadTTLIOAllPortValue"
//##protect##"functionStart_ReadTTLIOAllPortValue"
			returnValue = DllImport.i_PCI1710_ReadTTLIOAllPortValue(this.handle, moduleNumber, out value);
//##protect##"functionEnd_ReadTTLIOAllPortValue"
//##protect##"functionEnd_ReadTTLIOAllPortValue"
			return returnValue;
		}

		/// <summary>
		/// Sets one TTL output.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="channelNbr">Output to set (0: PD0, 1: PD1, 2 to 9: PA0 to PA7, 10 to 17: PB0 to PB7, 18 to 25: PC0 to PC7)</param>
		public int SetTTLIOChlOn(Byte moduleNumber, Byte channelNbr)
		{
			int returnValue;
//##protect##"functionStart_SetTTLIOChlOn"
//##protect##"functionStart_SetTTLIOChlOn"
			returnValue = DllImport.i_PCI1710_SetTTLIOChlOn(this.handle, moduleNumber, channelNbr);
//##protect##"functionEnd_SetTTLIOChlOn"
//##protect##"functionEnd_SetTTLIOChlOn"
			return returnValue;
		}

		/// <summary>
		/// Resets one TTL output.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="channelNbr">Output to reset (0: PD0, 1: PD1, 2 to 9: PA0 to PA7, 10 to 17: PB0 to PB7, 18 to 25: PC0 to PC7)</param>
		public int SetTTLIOChlOff(Byte moduleNumber, Byte channelNbr)
		{
			int returnValue;
//##protect##"functionStart_SetTTLIOChlOff"
//##protect##"functionStart_SetTTLIOChlOff"
			returnValue = DllImport.i_PCI1710_SetTTLIOChlOff(this.handle, moduleNumber, channelNbr);
//##protect##"functionEnd_SetTTLIOChlOff"
//##protect##"functionEnd_SetTTLIOChlOff"
			return returnValue;
		}

		/// <summary>
		/// Sets one TTL output.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portNbr">Number of the port of tha channel (0: I, 1: J, 2: A, 3: B, 4: C)</param>
		/// <param name="channelNbr">Output to set (from 0 to 7). For port I and J, only the output 0 is available</param>
		public int SetTTLIOChannelOn(Byte moduleNumber, Byte portNbr, Byte channelNbr)
		{
			int returnValue;
//##protect##"functionStart_SetTTLIOChannelOn"
//##protect##"functionStart_SetTTLIOChannelOn"
			returnValue = DllImport.i_PCI1710_SetTTLIOChannelOn(this.handle, moduleNumber, portNbr, channelNbr);
//##protect##"functionEnd_SetTTLIOChannelOn"
//##protect##"functionEnd_SetTTLIOChannelOn"
			return returnValue;
		}

		/// <summary>
		/// Resets one TTL output.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="portNbr">Number of the port of tha channel (0: I, 1: J, 2: A, 3: B, 4: C)</param>
		/// <param name="channelNbr">Output to set (from 0 to 7). For port I and J, only the output 0 is available</param>
		public int SetTTLIOChannelOff(Byte moduleNumber, Byte portNbr, Byte channelNbr)
		{
			int returnValue;
//##protect##"functionStart_SetTTLIOChannelOff"
//##protect##"functionStart_SetTTLIOChannelOff"
			returnValue = DllImport.i_PCI1710_SetTTLIOChannelOff(this.handle, moduleNumber, portNbr, channelNbr);
//##protect##"functionEnd_SetTTLIOChannelOff"
//##protect##"functionEnd_SetTTLIOChannelOff"
			return returnValue;
		}

#endregion
#region "SSI"

		/// <summary>
		/// Initialises the SSI on a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="profileLength">Length of the profile (in bits). The profile is the position length plus the turn counter length in bits (from 2 to 32)</param>
		/// <param name="positionLength">Length of the position (in bits). This value represents the current position in the current turn</param>
		/// <param name="turnCptLength">Length of the turn counter in bits (b_PositionLength + b_TurnCptLength must not be bigger than b_ProfileLength). This arugment can be put to 0. In this case, the counter is in single turn mode, and b_positionLength must be equal to b_ProfileLength</param>
		/// <param name="PCIInputClock">Frequency of the input clock (30: 30 MHz, 33: 33 MHz). See your PC's PCI clock in its manual</param>
		/// <param name="outputClock">Output clock (from 229 to 5 000 000 Hz for a 30 MHz PCI input clock, and from 252 to 5 000 000 Hz for a 30 MHz PCI input clock)</param>
		/// <param name="countingMode">Selectin of the counting mode (0: binary: a conversion is made, 1: Gray code: no conversion is made)</param>
		public int InitSSI(Byte moduleNumber, Byte profileLength, Byte positionLength, Byte turnCptLength, Byte PCIInputClock, UInt32 outputClock, Byte countingMode)
		{
			int returnValue;
//##protect##"functionStart_InitSSI"
//##protect##"functionStart_InitSSI"
			returnValue = DllImport.i_PCI1710_InitSSI(this.handle, moduleNumber, profileLength, positionLength, turnCptLength, PCIInputClock, outputClock, countingMode);
//##protect##"functionEnd_InitSSI"
//##protect##"functionEnd_InitSSI"
			return returnValue;
		}

		/// <summary>
		/// Initialises the SSI on a given module.
		/// The difference with the other initialization lies in the fact that datas are not formated.
		/// So the read values will have their parity bit, turn count and position will not be automatically separated and so on.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="profileLength">Length of the profile (in bits). The profile is the position length plus the turn counter length in bits (from 2 to 32)</param>
		/// <param name="PCIInputClock">Frequency of the input clock (30: 30 MHz, 33: 33 MHz). See your PC's PCI clock in its manual</param>
		/// <param name="outputClock">Output clock (from 229 to 5 000 000 Hz for a 30 MHz PCI input clock, and from 252 to 5 000 000 Hz for a 30 MHz PCI input clock)</param>
		public int InitSSIRawData(Byte moduleNumber, Byte profileLength, Byte PCIInputClock, UInt32 outputClock)
		{
			int returnValue;
//##protect##"functionStart_InitSSIRawData"
//##protect##"functionStart_InitSSIRawData"
			returnValue = DllImport.i_PCI1710_InitSSIRawData(this.handle, moduleNumber, profileLength, PCIInputClock, outputClock);
//##protect##"functionEnd_InitSSIRawData"
//##protect##"functionEnd_InitSSIRawData"
			return returnValue;
		}

		/// <summary>
		/// Reads one value of a given SSI counter.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="SSINbr">Number of the SSI counter</param>
		/// <param name="position">Position in the current turn</param>
		/// <param name="turn">Current turn number</param>
		public int Read1SSIValue(Byte moduleNumber, Byte SSINbr, out UInt32 position, out UInt32 turn)
		{
			int returnValue;
//##protect##"functionStart_Read1SSIValue"
//##protect##"functionStart_Read1SSIValue"
			returnValue = DllImport.i_PCI1710_Read1SSIValue(this.handle, moduleNumber, SSINbr, out position, out turn);
//##protect##"functionEnd_Read1SSIValue"
//##protect##"functionEnd_Read1SSIValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the raw value of a given SSI counter.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="SSINbr">Number of the SSI counter</param>
		/// <param name="valueArray">Array of the raw data</param>
		/// <param name="arraySize">Size of the array</param>
		public int Read1SSIRawDataValue(Byte moduleNumber, Byte SSINbr, out UInt32 valueArray, Byte arraySize)
		{
			int returnValue;
//##protect##"functionStart_Read1SSIRawDataValue"
//##protect##"functionStart_Read1SSIRawDataValue"
			returnValue = DllImport.i_PCI1710_Read1SSIRawDataValue(this.handle, moduleNumber, SSINbr, out valueArray, arraySize);
//##protect##"functionEnd_Read1SSIRawDataValue"
//##protect##"functionEnd_Read1SSIRawDataValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the values of all the SSI counters of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="position">Position in the current turn (at least 3 * sizeof(DWORD) must be allocated)</param>
		/// <param name="turn">Current turn number (at least 3 * sizeof(DWORD) must be allocated)</param>
		public int ReadAllSSIValue(Byte moduleNumber, UInt32 [] position, UInt32 [] turn)
		{
			int returnValue;
//##protect##"functionStart_ReadAllSSIValue"
//##protect##"functionStart_ReadAllSSIValue"
			returnValue = DllImport.i_PCI1710_ReadAllSSIValue(this.handle, moduleNumber, position, turn);
//##protect##"functionEnd_ReadAllSSIValue"
//##protect##"functionEnd_ReadAllSSIValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the raw values of all the SSI counters of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="valueArray">Array of the raw data</param>
		/// <param name="arraySize">Size of the array</param>
		public int ReadAllSSIRawDataValue(Byte moduleNumber, out UInt32 valueArray, Byte arraySize)
		{
			int returnValue;
//##protect##"functionStart_ReadAllSSIRawDataValue"
//##protect##"functionStart_ReadAllSSIRawDataValue"
			returnValue = DllImport.i_PCI1710_ReadAllSSIRawDataValue(this.handle, moduleNumber, out valueArray, arraySize);
//##protect##"functionEnd_ReadAllSSIRawDataValue"
//##protect##"functionEnd_ReadAllSSIRawDataValue"
			return returnValue;
		}

		/// <summary>
		/// Reads the selected digital input of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="channel">Channel to read (0..2)</param>
		/// <param name="value">Value of the channel (0: not active, 1: active)</param>
		public int ReadSSI1DigitalInput(Byte moduleNumber, Byte channel, out Byte value)
		{
			int returnValue;
//##protect##"functionStart_ReadSSI1DigitalInput"
//##protect##"functionStart_ReadSSI1DigitalInput"
			returnValue = DllImport.i_PCI1710_ReadSSI1DigitalInput(this.handle, moduleNumber, channel, out value);
//##protect##"functionEnd_ReadSSI1DigitalInput"
//##protect##"functionEnd_ReadSSI1DigitalInput"
			return returnValue;
		}

		/// <summary>
		/// Reads all the digital inputs of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="value">Mask of the channel status (0000 0XYZ -> bitZ: D0, bit Y: D1, bit X: D2)</param>
		public int ReadSSIAllDigitalInput(Byte moduleNumber, out Byte value)
		{
			int returnValue;
//##protect##"functionStart_ReadSSIAllDigitalInput"
//##protect##"functionStart_ReadSSIAllDigitalInput"
			returnValue = DllImport.i_PCI1710_ReadSSIAllDigitalInput(this.handle, moduleNumber, out value);
//##protect##"functionEnd_ReadSSIAllDigitalInput"
//##protect##"functionEnd_ReadSSIAllDigitalInput"
			return returnValue;
		}

		/// <summary>
		/// Sets on all the digital output of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int SetSSIDigitalOutputOn(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_SetSSIDigitalOutputOn"
//##protect##"functionStart_SetSSIDigitalOutputOn"
			returnValue = DllImport.i_PCI1710_SetSSIDigitalOutputOn(this.handle, moduleNumber);
//##protect##"functionEnd_SetSSIDigitalOutputOn"
//##protect##"functionEnd_SetSSIDigitalOutputOn"
			return returnValue;
		}

		/// <summary>
		/// Sets off all the digital output of a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int SetSSIDigitalOutputOff(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_SetSSIDigitalOutputOff"
//##protect##"functionStart_SetSSIDigitalOutputOff"
			returnValue = DllImport.i_PCI1710_SetSSIDigitalOutputOff(this.handle, moduleNumber);
//##protect##"functionEnd_SetSSIDigitalOutputOff"
//##protect##"functionEnd_SetSSIDigitalOutputOff"
			return returnValue;
		}

		/// <summary>
		/// Starts a SSI acquisition on a given module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		public int StartSSIAcquisition(Byte moduleNumber)
		{
			int returnValue;
//##protect##"functionStart_StartSSIAcquisition"
//##protect##"functionStart_StartSSIAcquisition"
			returnValue = DllImport.i_PCI1710_StartSSIAcquisition(this.handle, moduleNumber);
//##protect##"functionEnd_StartSSIAcquisition"
//##protect##"functionEnd_StartSSIAcquisition"
			return returnValue;
		}

		/// <summary>
		/// Gets the status of the SSI acquisition.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="status">Status of the SSI acquisition (0: finished, 1: running)</param>
		public int GetSSIAcquisitionStatus(Byte moduleNumber, out Byte status)
		{
			int returnValue;
//##protect##"functionStart_GetSSIAcquisitionStatus"
//##protect##"functionStart_GetSSIAcquisitionStatus"
			returnValue = DllImport.i_PCI1710_GetSSIAcquisitionStatus(this.handle, moduleNumber, out status);
//##protect##"functionEnd_GetSSIAcquisitionStatus"
//##protect##"functionEnd_GetSSIAcquisitionStatus"
			return returnValue;
		}

		/// <summary>
		/// Gets the value of a given counter.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="SSINumber">Number of the counter (from 0 to 2)</param>
		/// <param name="position">Position in the current turn</param>
		/// <param name="turn">Current turn number</param>
		public int GetSSIValue(Byte moduleNumber, Byte SSINumber, out UInt32 position, out UInt32 turn)
		{
			int returnValue;
//##protect##"functionStart_GetSSIValue"
//##protect##"functionStart_GetSSIValue"
			returnValue = DllImport.i_PCI1710_GetSSIValue(this.handle, moduleNumber, SSINumber, out position, out turn);
//##protect##"functionEnd_GetSSIValue"
//##protect##"functionEnd_GetSSIValue"
			return returnValue;
		}

		/// <summary>
		/// Gets the raw value of a given SSI counter.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="SSINumber">Number of the counter (from 0 to 2)</param>
		/// <param name="valueArray">Array of the raw data</param>
		/// <param name="arraySize">Size of the array</param>
		public int GetSSIRawDataValue(Byte moduleNumber, Byte SSINumber, out UInt32 valueArray, Byte arraySize)
		{
			int returnValue;
//##protect##"functionStart_GetSSIRawDataValue"
//##protect##"functionStart_GetSSIRawDataValue"
			returnValue = DllImport.i_PCI1710_GetSSIRawDataValue(this.handle, moduleNumber, SSINumber, out valueArray, arraySize);
//##protect##"functionEnd_GetSSIRawDataValue"
//##protect##"functionEnd_GetSSIRawDataValue"
			return returnValue;
		}

#endregion
#region "ETM"

		/// <summary>
		/// Configures all ETM counters of the selected module.
		/// The parameters dw_Timing und dw_TimingUnit determine the time base for the measurement.
		/// pdw_RealTiming returns the correct time value.
		/// Call this function before you call another function that accesses the ETM counter.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="clockSelection">Selection of the reference clock (30: PCI clock (30 MHz), 33: PCI clock (33 MHz), 40: 40 MHz onboard quartz)</param>
		/// <param name="timingUnit">Unit of the time base (0: ns 1: us 2: ms)</param>
		/// <param name="timing">Value of the time base</param>
		/// <param name="realTiming">Correct value of the time base. Returns the value that corresponds best with the value entered in dw_Timing</param>
		public int InitETM(Byte moduleNumber, Byte clockSelection, Byte timingUnit, UInt32 timing, out UInt32 realTiming)
		{
			int returnValue;
//##protect##"functionStart_InitETM"
//##protect##"functionStart_InitETM"
			returnValue = DllImport.i_PCI1710_InitETM(this.handle, moduleNumber, clockSelection, timingUnit, timing, out realTiming);
//##protect##"functionEnd_InitETM"
//##protect##"functionEnd_InitETM"
			return returnValue;
		}

		/// <summary>
		/// Enables the ETM counter of the selected module.
		/// The function i_PCI1710_InitETM has to be called first.
		/// If interrupts are enabled, the ETM counter generates an interrupt after each trigger signal.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="edgeLevel">b_EdgeLevel Edge selection for time measurement (0: Measures the low level time, 1: Measures the high level time)</param>
		/// <param name="triggerLevel">Selection of the trigger level (0: Trigger at low level, 1: Trigger at high level)</param>
		/// <param name="cycleMode">Mode selection (0: Single mode, 1: Continuous Mode). Each trigger stops the measurement and starts a new cycle.</param>
		/// <param name="firstTriggerMode">Mode of the first trigger 0: The measurement of the first edge time starts after calling the function i_PCI1710_EnableETM. 1: The measurement of the first edge time starts after the next trigger signal.</param>
		/// <param name="interruptEnable">Enables or disables the interrupt function. (0: interrupts disabled, 1: interrupts enabled)</param>
		public int EnableETM(Byte moduleNumber, Byte ETM, Byte edgeLevel, Byte triggerLevel, Byte cycleMode, Byte firstTriggerMode, Byte interruptEnable)
		{
			int returnValue;
//##protect##"functionStart_EnableETM"
//##protect##"functionStart_EnableETM"
			returnValue = DllImport.i_PCI1710_EnableETM(this.handle, moduleNumber, ETM, edgeLevel, triggerLevel, cycleMode, firstTriggerMode, interruptEnable);
//##protect##"functionEnd_EnableETM"
//##protect##"functionEnd_EnableETM"
			return returnValue;
		}

		/// <summary>
		/// Disables the ETM counter of the selected module
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		public int DisableETM(Byte moduleNumber, Byte ETM)
		{
			int returnValue;
//##protect##"functionStart_DisableETM"
//##protect##"functionStart_DisableETM"
			returnValue = DllImport.i_PCI1710_DisableETM(this.handle, moduleNumber, ETM);
//##protect##"functionEnd_DisableETM"
//##protect##"functionEnd_DisableETM"
			return returnValue;
		}

		/// <summary>
		/// Returns the information about the ETM initialisation for the selected module
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="timingUnit">Unit of the time base (0: ns 1: us 2: ms)</param>
		/// <param name="timing">Value of the time base</param>
		/// <param name="edgeLevel">b_EdgeLevel Edge selection for time measurement (0: Measures the low level time, 1: Measures the high level time)</param>
		/// <param name="triggerLevel">Selection of the trigger level (0: Trigger at low level, 1: Trigger at high level)</param>
		/// <param name="cycleMode">Mode selection (0: Single mode, 1: Continuous Mode). Each trigger stops the measurement and starts a new cycle.</param>
		/// <param name="firstTriggerMode">Mode of the first trigger 0: The measurement of the first edge time starts after calling the function i_PCI1710_EnableETM. 1: The measurement of the first edge time starts after the next trigger signal.</param>
		/// <param name="interruptEnable">Enables or disables the interrupt function. (0: interrupts disabled, 1: interrupts enabled)</param>
		/// <param name="enable">Returns whether the ETM is enabled or disabled. (0: ETM disabled, 1: ETM enabled)</param>
		public int GetETMInitialisation(Byte moduleNumber, Byte ETM, out Byte timingUnit, out UInt32 timing, out Byte edgeLevel, out Byte triggerLevel, out Byte cycleMode, out Byte firstTriggerMode, out Byte interruptEnable, out Byte enable)
		{
			int returnValue;
//##protect##"functionStart_GetETMInitialisation"
//##protect##"functionStart_GetETMInitialisation"
			returnValue = DllImport.i_PCI1710_GetETMInitialisation(this.handle, moduleNumber, ETM, out timingUnit, out timing, out edgeLevel, out triggerLevel, out cycleMode, out firstTriggerMode, out interruptEnable, out enable);
//##protect##"functionEnd_GetETMInitialisation"
//##protect##"functionEnd_GetETMInitialisation"
			return returnValue;
		}

		/// <summary>
		/// Returns the ETM state of the selected module
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="ETMStatus">The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: Transition has been realised)</param>
		public int GetETMProgressStatus(Byte moduleNumber, Byte ETM, out Byte ETMStatus)
		{
			int returnValue;
//##protect##"functionStart_GetETMProgressStatus"
//##protect##"functionStart_GetETMProgressStatus"
			returnValue = DllImport.i_PCI1710_GetETMProgressStatus(this.handle, moduleNumber, ETM, out ETMStatus);
//##protect##"functionEnd_GetETMProgressStatus"
//##protect##"functionEnd_GetETMProgressStatus"
			return returnValue;
		}

		/// <summary>
		/// Returns the ETM state and the time value after a stop signal on the selected module.
		/// This function is only available when you disable the interrupt function.
		/// The returned value is not the actual measured time value. You must use the function i_PCI1710_ConvertETMValue or apply the following formula in order to calculate the time value:
		/// Time value = pdw_ETMValue x pdw_RealTiming
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="timeOut">Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)</param>
		/// <param name="ETMStatus">The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: Transition has been realised, 4: Timeout reached)</param>
		/// <param name="ETMValue">ETM time value.</param>
		public int ReadETMValue(Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out UInt32 ETMValue)
		{
			int returnValue;
//##protect##"functionStart_ReadETMValue"
//##protect##"functionStart_ReadETMValue"
			returnValue = DllImport.i_PCI1710_ReadETMValue(this.handle, moduleNumber, ETM, timeOut, out ETMStatus, out ETMValue);
//##protect##"functionEnd_ReadETMValue"
//##protect##"functionEnd_ReadETMValue"
			return returnValue;
		}

		/// <summary>
		/// Returns the ETM status and the total time value after a stop signal occurred on the selected ETM module.
		/// This function is only available if you have disabled the interrupt function.
		/// The returned value is not the actual measured time value. You must use the function i_PCI1710_ConvertETMValue or apply the following formula in order to calculate the time value:
		/// pdw_ETMValue x pdw_RealTiming
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="timeOut">Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)</param>
		/// <param name="ETMStatus">The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: Transition has been realised, 4: Timeout reached)</param>
		/// <param name="ETMValue">ETM time value.</param>
		public int ReadETMTotalTime(Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out UInt32 ETMValue)
		{
			int returnValue;
//##protect##"functionStart_ReadETMTotalTime"
//##protect##"functionStart_ReadETMTotalTime"
			returnValue = DllImport.i_PCI1710_ReadETMTotalTime(this.handle, moduleNumber, ETM, timeOut, out ETMStatus, out ETMValue);
//##protect##"functionEnd_ReadETMTotalTime"
//##protect##"functionEnd_ReadETMTotalTime"
			return returnValue;
		}

		/// <summary>
		/// Returns the ETM status and the duty cycle value after a stop signal occurred on the selected ETM module.
		/// This function is only available if you have disabled the interrupt function.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETM">Selection of the ETM counter (0 or 1)</param>
		/// <param name="timeOut">Selection of the timeout in ms. (0 to 65535, 0: Blocking until a stop signal has arrived)</param>
		/// <param name="ETMStatus">The ETM state. (0: No start trigger arrived, 1: A start trigger has arrived, 2: A stop trigger has arrived, 3: Transition has been realised, 4: Timeout reached)</param>
		/// <param name="dutyCycle">ETM duty cycle.</param>
		public int ReadETMDutyCycleValue(Byte moduleNumber, Byte ETM, UInt32 timeOut, out Byte ETMStatus, out Double dutyCycle)
		{
			int returnValue;
//##protect##"functionStart_ReadETMDutyCycleValue"
//##protect##"functionStart_ReadETMDutyCycleValue"
			returnValue = DllImport.i_PCI1710_ReadETMDutyCycleValue(this.handle, moduleNumber, ETM, timeOut, out ETMStatus, out dutyCycle);
//##protect##"functionEnd_ReadETMDutyCycleValue"
//##protect##"functionEnd_ReadETMDutyCycleValue"
			return returnValue;
		}

		/// <summary>
		/// Converts the measured ETM time in hours, minutes, seconds, milliseconds, microseconds and nanoseconds.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="ETMValue">ETM time value. See i_PCI1710_ReadETMValue</param>
		/// <param name="hour">Time measurement in hours</param>
		/// <param name="minute">Time measurement in minutes</param>
		/// <param name="second">Time measurement in seconds</param>
		/// <param name="millisecond">Time measurement in milliseconds</param>
		/// <param name="microsecond">Time measurement in microseconds</param>
		/// <param name="nanosecond">Time measurement in nanoseconds</param>
		public int ConvertETMValue(Byte moduleNumber, UInt32 ETMValue, out UInt32 hour, out Byte minute, out Byte second, out UInt32 millisecond, out UInt32 microsecond, out UInt32 nanosecond)
		{
			int returnValue;
//##protect##"functionStart_ConvertETMValue"
//##protect##"functionStart_ConvertETMValue"
			returnValue = DllImport.i_PCI1710_ConvertETMValue(this.handle, moduleNumber, ETMValue, out hour, out minute, out second, out millisecond, out microsecond, out nanosecond);
//##protect##"functionEnd_ConvertETMValue"
//##protect##"functionEnd_ConvertETMValue"
			return returnValue;
		}

#endregion
#region "PWM"

		/// <summary>
		/// This function configures the selected PWM from the selected module.
		/// The dw_LowTiming, dw_HighTiming and b_TimingUnit determine the low/high base timing for the period.
		/// The pdw_RealLowTiming and pdw_RealHighTiming return the real timing value.
		/// You must call this function before calling any other PWM function.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PWM">Index of the selected PWM (0 or 1)</param>
		/// <param name="timingUnit">Timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)</param>
		/// <param name="lowTiming">Low base timing value</param>
		/// <param name="highTiming">High base timing value</param>
		/// <param name="realLowTiming">Real low base timing value</param>
		/// <param name="realHighTiming">Real high base timing value</param>
		public int InitPWM(Byte moduleNumber, Byte PWM, Byte timingUnit, UInt32 lowTiming, UInt32 highTiming, out UInt32 realLowTiming, out UInt32 realHighTiming)
		{
			int returnValue;
//##protect##"functionStart_InitPWM"
//##protect##"functionStart_InitPWM"
			returnValue = DllImport.i_PCI1710_InitPWM(this.handle, moduleNumber, PWM, timingUnit, lowTiming, highTiming, out realLowTiming, out realHighTiming);
//##protect##"functionEnd_InitPWM"
//##protect##"functionEnd_InitPWM"
			return returnValue;
		}

		/// <summary>
		/// Sets a new timing.
		/// The dw_LowTiming, dw_HighTiming and b_TimingUnit determine the low/high base timing for the period.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PWM">Index of the selected PWM (0 or 1)</param>
		/// <param name="timingUnit">Timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)</param>
		/// <param name="lowTiming">Low base timing value</param>
		/// <param name="highTiming">High base timing value</param>
		public int SetNewPWMTiming(Byte moduleNumber, Byte PWM, Byte timingUnit, UInt32 lowTiming, UInt32 highTiming)
		{
			int returnValue;
//##protect##"functionStart_SetNewPWMTiming"
//##protect##"functionStart_SetNewPWMTiming"
			returnValue = DllImport.i_PCI1710_SetNewPWMTiming(this.handle, moduleNumber, PWM, timingUnit, lowTiming, highTiming);
//##protect##"functionEnd_SetNewPWMTiming"
//##protect##"functionEnd_SetNewPWMTiming"
			return returnValue;
		}

		/// <summary>
		/// Enables the selected PWM of the selected module.
		/// The i_PCI1710_InitPWM function must be called before calling this function.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PWM">Index of the selected PWM (0 or 1)</param>
		/// <param name="startLevel">Start period level selection (0: the period will start with a low level, 1: the period will start with a high level)</param>
		/// <param name="stopMode">Stop mode selection (0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function, 1: the PWM will be stopped after the end of the last period after the call of the disable function)</param>
		/// <param name="stopLevel">Stop PWM level selection (0: the output signal will keep its level after the call of the i_PCI1710_DisablePWM function, 1: the output signal will be set to low after the call of the disable function, 2: the output signal will be set to high after the call of the disable function)</param>
		/// <param name="externGate">Extern gate action selection (0: extern gate signal not used, 1: extern gate signal used)</param>
		/// <param name="interruptEnable">Enable or disable the interrupt (0: disable the PWM interrupt, 1: an interrupt will occur after each end of state)</param>
		public int EnablePWM(Byte moduleNumber, Byte PWM, Byte startLevel, Byte stopMode, Byte stopLevel, Byte externGate, Byte interruptEnable)
		{
			int returnValue;
//##protect##"functionStart_EnablePWM"
//##protect##"functionStart_EnablePWM"
			returnValue = DllImport.i_PCI1710_EnablePWM(this.handle, moduleNumber, PWM, startLevel, stopMode, stopLevel, externGate, interruptEnable);
//##protect##"functionEnd_EnablePWM"
//##protect##"functionEnd_EnablePWM"
			return returnValue;
		}

		/// <summary>
		/// Disables the selected PWM of the selected module.
		/// The output signal level depends of the configuration of the PWM parameter (see the b_StartLevel, b_StopMode and b_StopLevel parameters of the i_PCI1710_EnablePWM function).
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PWM">Index of the selected PWM (0 or 1)</param>
		public int DisablePWM(Byte moduleNumber, Byte PWM)
		{
			int returnValue;
//##protect##"functionStart_DisablePWM"
//##protect##"functionStart_DisablePWM"
			returnValue = DllImport.i_PCI1710_DisablePWM(this.handle, moduleNumber, PWM);
//##protect##"functionEnd_DisablePWM"
//##protect##"functionEnd_DisablePWM"
			return returnValue;
		}

		/// <summary>
		/// Returns the selected PWM initialization of the selected module.
		/// The i_PCI1710_InitPWM function must be called before calling this function.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="moduleNumber">Number of the module to be configured (from 0 to 3)</param>
		/// <param name="PWM">Selected PWM (0 or 1)</param>
		/// <param name="timingUnit">Returns the base timing unit (0: ns, 1: us, 2: ms, 3: sec or 4: min)</param>
		/// <param name="lowTiming">Returns the low base timing value</param>
		/// <param name="highTiming">Returns the high base timing value</param>
		/// <param name="startLevel">Returns the start period level selection (0: the period will start with a low level, 1: the period will start with a high level)</param>
		/// <param name="stopMode">Returns the stop mode selection (0: the PWM will be stopped directly after the call of the i_PCI1710_DisablePWM function and will break the last period, 1: the PWM will end its last period before being stopped after the call of the disable function)</param>
		/// <param name="stopLevel">Returns the stop level selection (0: the output signal will keep the level after the call of the i_PCI1710_DisablePWM function, 1: the output signal will be stopped at low after the call of the disable function, 2: the output signal will be set to high after the call of the disable function)</param>
		/// <param name="externGate">Indicates if the extern gate action is used (0: not used, 1: used)</param>
		/// <param name="interruptEnable">Indicates if the interrupt are enabled or not (0: disabled, 1: enabled)</param>
		/// <param name="enable">Indicates if the PWM is enabled or not (0: disabled, 1: enabled)</param>
		public int GetPWMInitialisation(Byte moduleNumber, Byte PWM, out Byte timingUnit, out UInt32 lowTiming, out UInt32 highTiming, out Byte startLevel, out Byte stopMode, out Byte stopLevel, out Byte externGate, out Byte interruptEnable, out Byte enable)
		{
			int returnValue;
//##protect##"functionStart_GetPWMInitialisation"
//##protect##"functionStart_GetPWMInitialisation"
			returnValue = DllImport.i_PCI1710_GetPWMInitialisation(this.handle, moduleNumber, PWM, out timingUnit, out lowTiming, out highTiming, out startLevel, out stopMode, out stopLevel, out externGate, out interruptEnable, out enable);
//##protect##"functionEnd_GetPWMInitialisation"
//##protect##"functionEnd_GetPWMInitialisation"
			return returnValue;
		}

		/// <summary>
		/// Returns the selected PWM status of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		/// <param name="PWM">Selected PWM (0 or 1)</param>
		/// <param name="PWMOutputStatus">Returns the PWM output level status (0: low or 1: high)</param>
		/// <param name="externGateStatus">Returns the extern gate level status (0: low or 1: high)</param>
		public int GetPWMStatus(Byte modulNbr, Byte PWM, out Byte PWMOutputStatus, out Byte externGateStatus)
		{
			int returnValue;
//##protect##"functionStart_GetPWMStatus"
//##protect##"functionStart_GetPWMStatus"
			returnValue = DllImport.i_PCI1710_GetPWMStatus(this.handle, modulNbr, PWM, out PWMOutputStatus, out externGateStatus);
//##protect##"functionEnd_GetPWMStatus"
//##protect##"functionEnd_GetPWMStatus"
			return returnValue;
		}

		/// <summary>
		/// Reads the status of the selected PWM digital input of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		/// <param name="inputChannel">Selected digital input (0 to 2)</param>
		/// <param name="channelStatus">Returns the digital inptut channel status (0: reset or 1: set)</param>
		public int ReadPWM1DigitalInput(Byte modulNbr, Byte inputChannel, out Byte channelStatus)
		{
			int returnValue;
//##protect##"functionStart_ReadPWM1DigitalInput"
//##protect##"functionStart_ReadPWM1DigitalInput"
			returnValue = DllImport.i_PCI1710_ReadPWM1DigitalInput(this.handle, modulNbr, inputChannel, out channelStatus);
//##protect##"functionEnd_ReadPWM1DigitalInput"
//##protect##"functionEnd_ReadPWM1DigitalInput"
			return returnValue;
		}

		/// <summary>
		/// Reads the status of all the PWM digital inputs of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		/// <param name="inputStatus">Digital inputs channel status</param>
		public int ReadPWMAllDigitalInputs(Byte modulNbr, out Byte inputStatus)
		{
			int returnValue;
//##protect##"functionStart_ReadPWMAllDigitalInputs"
//##protect##"functionStart_ReadPWMAllDigitalInputs"
			returnValue = DllImport.i_PCI1710_ReadPWMAllDigitalInputs(this.handle, modulNbr, out inputStatus);
//##protect##"functionEnd_ReadPWMAllDigitalInputs"
//##protect##"functionEnd_ReadPWMAllDigitalInputs"
			return returnValue;
		}

		/// <summary>
		/// Enables or disables to set manually the digital output H of the selected module.
		/// When the PWM 0 will be enabled for the first time, the digital output manual setting will be considered as disabled, which means that it would the PWM 0 which will control the digital output of the selected module.
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		/// <param name="flag">Enable/disable flag (0: disable the manual setting, the output H is controlled parallely to the PWM0, or 1: enable the manual setting, the output H will be set via the i_PCI1710_SetPWMDigitalOutputOn function or reset via the i_PCI1710_SetPWMDigitalOutputOff function)</param>
		public int EnableDisablePWMDigitalOutputManualSetting(Byte modulNbr, Byte flag)
		{
			int returnValue;
//##protect##"functionStart_EnableDisablePWMDigitalOutputManualSetting"
//##protect##"functionStart_EnableDisablePWMDigitalOutputManualSetting"
			returnValue = DllImport.i_PCI1710_EnableDisablePWMDigitalOutputManualSetting(this.handle, modulNbr, flag);
//##protect##"functionEnd_EnableDisablePWMDigitalOutputManualSetting"
//##protect##"functionEnd_EnableDisablePWMDigitalOutputManualSetting"
			return returnValue;
		}

		/// <summary>
		/// Sets on the digital output H of the selected PWM of the selected module.
		/// The i_PCI1710_EnableDisablePWMDigitalOutputSetting function must be called before calling this function
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		public int SetPWMDigitalOutputOn(Byte modulNbr)
		{
			int returnValue;
//##protect##"functionStart_SetPWMDigitalOutputOn"
//##protect##"functionStart_SetPWMDigitalOutputOn"
			returnValue = DllImport.i_PCI1710_SetPWMDigitalOutputOn(this.handle, modulNbr);
//##protect##"functionEnd_SetPWMDigitalOutputOn"
//##protect##"functionEnd_SetPWMDigitalOutputOn"
			return returnValue;
		}

		/// <summary>
		/// Sets off the digital output H of the selected PWM of the selected module.
		/// The i_PCI1710_EnableDisablePWMDigitalOutputSetting function must be called before calling this function
		/// </summary>
		/// <param name="deviceHandle">Handle of the board</param>
		/// <param name="modulNbr">Number of the module to configure (0 to 3)</param>
		public int SetPWMDigitalOutputOff(Byte modulNbr)
		{
			int returnValue;
//##protect##"functionStart_SetPWMDigitalOutputOff"
//##protect##"functionStart_SetPWMDigitalOutputOff"
			returnValue = DllImport.i_PCI1710_SetPWMDigitalOutputOff(this.handle, modulNbr);
//##protect##"functionEnd_SetPWMDigitalOutputOff"
//##protect##"functionEnd_SetPWMDigitalOutputOff"
			return returnValue;
		}

#endregion
#region "User"
//##protect##"AssemblyUserCode"
//##protect##"AssemblyUserCode"
#endregion
    }
}
