using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace ReadTimer
{
    public partial class ReadTimer : Form
    {
        private PCI1710_NET.PCI1710 board;
        int interruptCounter;

        public ReadTimer()
        {
            InitializeComponent();
        }

        private void ReadTimer_Load(object sender, EventArgs e)
        {
            // Initialize the combo box default values
            modNumCombo.Text   = modNumCombo.Items[0].ToString();
            timerNumCombo.Text = timerNumCombo.Items[0].ToString();
            modeCombo.Text     = modeCombo.Items[0].ToString();
            clkSrcCombo.Text   = clkSrcCombo.Items[0].ToString();
            clkLvlCombo.Text   = clkLvlCombo.Items[0].ToString();
            outLvlCombo.Text   = outLvlCombo.Items[0].ToString();
            gateCombo.Text     = gateCombo.Items[0].ToString();
        }

        private void ReadTimer_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.board != null)
            {
                if (stopButton.Enabled == true)
                    stopButton_Click(null, null);
                this.board.ResetBoardIntRoutine();
            }
        }

        void interruptEventReceived(object source, PCI1710_NET.InterruptEventArgs args)
        {
            // Increment the interrupt counter
            this.interruptCounter++;
        }

        private void startButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                // Enable interruptions
                ret = this.board.SetBoardIntRoutine();
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in SetBoardIntRoutine!", "SetBoardIntRoutine error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                this.board.InterruptEventReceived += new PCI1710_NET.PCI1710.InterruptEventHandler(interruptEventReceived);
            }

            // Initialize and enable the selected timer
            ret = this.board.InitTimer((Byte)modNumCombo.SelectedIndex,
                                       (Byte)timerNumCombo.SelectedIndex,
                                       (Byte)modeCombo.SelectedIndex,
                                       (UInt32)reloadUD.Value,
                                       (Byte)clkSrcCombo.SelectedIndex,
                                       (Byte)clkLvlCombo.SelectedIndex,
                                       (Byte)outLvlCombo.SelectedIndex,
                                       (Byte)gateCombo.SelectedIndex);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitTimer!", "InitTimer error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            ret = this.board.EnableTimer((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex, 1);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in EnableTimer!", "EnableTimer error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Reset the interrupt counter
            this.interruptCounter = 0;

            // Disable the user interface while the sample runs
            modNumCombo.Enabled = timerNumCombo.Enabled = modeCombo.Enabled = reloadUD.Enabled = false;
            clkSrcCombo.Enabled = clkLvlCombo.Enabled = outLvlCombo.Enabled = gateCombo.Enabled = false;
            startButton.Enabled = false;
            triggerButton.Enabled = stopButton.Enabled = true;

            // Start the refresh timer
            refreshTimer.Start();
        }

        private void stopButton_Click(object sender, EventArgs e)
        {
            // Stop the refresh timer
            refreshTimer.Stop();

            // Reset the board state
            int ret = this.board.DisableTimer((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in DisableTimer!", "DisableTimer error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Enable the user interface again
            modNumCombo.Enabled = timerNumCombo.Enabled = modeCombo.Enabled = reloadUD.Enabled = true;
            clkSrcCombo.Enabled = clkLvlCombo.Enabled = outLvlCombo.Enabled = gateCombo.Enabled = true;
            startButton.Enabled = true;
            triggerButton.Enabled = stopButton.Enabled = false;
        }

        private void triggerButton_Click(object sender, EventArgs e)
        {
            // Write the reload value to trigger the timer
            int ret = this.board.WriteTimerValue((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex, (UInt32)reloadUD.Value);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in WriteTimerValue!", "WriteTimerValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }

        private void refreshTimer_Tick(object sender, EventArgs e)
        {
            int ret;
            UInt32 timerValue;
            Byte outputLevel;
            Byte timerStatus;
            
            // Read the timer status
            ret = this.board.ReadTimerValue((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex, out timerValue);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in ReadTimerValue!", "ReadTimerValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            ret = this.board.GetTimerOutputLevel((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex, out outputLevel);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in GetTimerOutputLevel!", "GetTimerOutputLevel error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            ret = this.board.GetTimerProgressStatusEx((Byte)modNumCombo.SelectedIndex, (Byte)timerNumCombo.SelectedIndex, out timerStatus);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in GetTimerProgressStatusEx!", "GetTimerProgressStatusEx error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Update the display
            interruptCntLabel.Text = interruptCounter.ToString();
            progressLabel.Text = timerStatus.ToString();
            valueLabel.Text = timerValue.ToString();
            outputLabel.Text = outputLevel.ToString();
        }
    }
}
