using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace ReadTimer
{
    public partial class PulseEncoder : Form
    {
        private PCI1710_NET.PCI1710 board;

        private int interruptCounter;

        public PulseEncoder()
        {
            InitializeComponent();
        }

        private void ReadTimer_Load(object sender, EventArgs e)
        {
            // Initialize the combo box default values
            modNumCombo.Text    = modNumCombo.Items[0].ToString();
            pulEncCombo.Text    = pulEncCombo.Items[0].ToString();
            inpLevSelCombo.Text = inpLevSelCombo.Items[0].ToString();
            cycSelCombo.Text    = cycSelCombo.Items[0].ToString();
            triOutActCombo.Text = triOutActCombo.Items[0].ToString();
            interruptCombo.Text = interruptCombo.Items[0].ToString();
        }

        private void ReadTimer_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.board != null)
            {
                if (disablePulseEncoderButton.Enabled == true)
                    disablePulseEncoderButton_Click(null, null);
                this.board.ResetBoardIntRoutine();
            }
        }

        void interruptEventReceived(object source, PCI1710_NET.InterruptEventArgs args)
        {
            if (args.fifoOverflow)
            {
                this.disablePulseEncoderButton_Click(null, null);
                MessageBox.Show("FIFO overflow", "FIFO overflow error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            // Increment the interrupt counter
            this.interruptCounter++;
        }

        private void iniAndEnaButton_Click(object sender, EventArgs e)
        {
            int ret = 0;

            // First, open a board if needed
            if (this.board == null)
            {
                try
                {
                    this.board = PCI1710_NET.PCI1710.OpenBoard(0);
                    if (this.board == null)
                        throw new Exception();
                }
                catch (Exception)
                {
                    MessageBox.Show("Unable to open the board!\nPlease make sure that the board is plugged in and the driver is correctly installed.", "OpenBoard error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                // Enable interruptions
                ret = this.board.SetBoardIntRoutine();
                if (ret != 0)
                {
                    MessageBox.Show("Error " + ret + " in SetBoardIntRoutine!", "SetBoardIntRoutine error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                this.board.InterruptEventReceived += new PCI1710_NET.PCI1710.InterruptEventHandler(interruptEventReceived);
            }

            // Initialize and enable the selected pulse encoder
            ret = this.board.InitPulseEncoder((Byte)modNumCombo.SelectedIndex,
                                              (Byte)pulEncCombo.SelectedIndex,
                                              (Byte)inpLevSelCombo.SelectedIndex,
                                              (Byte)triOutActCombo.SelectedIndex,
                                              (UInt32)startValUD.Value);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in InitPulseEncoder!", "InitPulseEncoder error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            ret = this.board.EnablePulseEncoder((Byte)modNumCombo.SelectedIndex, (Byte)pulEncCombo.SelectedIndex, (Byte)cycSelCombo.SelectedIndex, (Byte)interruptCombo.SelectedIndex);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in EnablePulseEncoder!", "EnablePulseEncoder error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Reset the interrupt counter
            this.interruptCounter = 0;

            // Disable the user interface while the sample runs
            IniAndEnaButton.Enabled = modNumCombo.Enabled = pulEncCombo.Enabled = inpLevSelCombo.Enabled = startValUD.Enabled = cycSelCombo.Enabled = interruptCombo.Enabled = triOutActCombo.Enabled = false;
            disablePulseEncoderButton.Enabled = true;
            writePulseEncoderButton.Enabled   = true;

            // Start the refresh timer
            refreshTimer.Start();
        }

        private void disablePulseEncoderButton_Click(object sender, EventArgs e)
        {
            // Stop the refresh timer
            refreshTimer.Stop();

            // Reset the board state
            int ret = this.board.DisablePulseEncoder((Byte)modNumCombo.SelectedIndex, (Byte)pulEncCombo.SelectedIndex);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in DisablePulseEncoder!", "DisablePulseEncoder error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Enable the user interface again
            IniAndEnaButton.Enabled = modNumCombo.Enabled = pulEncCombo.Enabled = inpLevSelCombo.Enabled = startValUD.Enabled = cycSelCombo.Enabled = interruptCombo.Enabled = triOutActCombo.Enabled = true;
            disablePulseEncoderButton.Enabled = false;
            writePulseEncoderButton.Enabled = false;
        }

        private void refreshTimer_Tick(object sender, EventArgs e)
        {
            int ret;
            UInt32 pulseEncoderValue;
            Byte pulseEncoderStatus;
            
            // Read the pulse encoder status
            ret = this.board.ReadPulseEncoderValue((Byte)modNumCombo.SelectedIndex, (Byte)pulEncCombo.SelectedIndex, out pulseEncoderValue);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in ReadPulseEncoderValue!", "ReadPulseEncoderValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            ret = this.board.ReadPulseEncoderStatus((Byte)modNumCombo.SelectedIndex, (Byte)pulEncCombo.SelectedIndex, out pulseEncoderStatus);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in ReadPulseEncoderStatus!", "ReadPulseEncoderStatus error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            // Update the display
            interruptCntLabel.Text = interruptCounter.ToString();
            statusLabel.Text = pulseEncoderStatus.ToString();
            valueLabel.Text = pulseEncoderValue.ToString();
        }

        private void writePulseEncoderButton_Click(object sender, EventArgs e)
        {
            // Reset the board state
            int ret = this.board.WritePulseEncoderValue((Byte)modNumCombo.SelectedIndex, (Byte)pulEncCombo.SelectedIndex, (UInt32) writeValUD.Value);
            if (ret != 0)
            {
                MessageBox.Show("Error " + ret + " in WritePulseEncoderValue!", "WritePulseEncoderValue error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }
}
